@@ -7,12 +7,13 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
+#include <RDGeneral/export.h>
 #ifndef __RD_DISCRETEDISTMAT_H__
 #define __RD_DISCRETEDISTMAT_H__
 #include "DiscreteValueVect.h"
 
 namespace RDKit {
-class DiscreteDistMat {
+class RDKIT_DATASTRUCTS_EXPORT DiscreteDistMat {
  public:
   DiscreteDistMat();
   ~DiscreteDistMat(){};
