@@ -19,7 +19,7 @@
 #ifdef WIN32
 #include <ios>
 #endif
-#include <boost/cstdint.hpp>
+#include <cstdint>
 
 // """ -------------------------------------------------------
 //
@@ -296,7 +296,7 @@ std::string SparseBitVect::toString() const {
   std::stringstream ss(std::ios_base::binary | std::ios_base::out |
                        std::ios_base::in);
 
-  boost::int32_t tInt = ci_BITVECT_VERSION * -1;
+  std::int32_t tInt = ci_BITVECT_VERSION * -1;
   RDKit::streamWrite(ss, tInt);
   tInt = d_size;
   RDKit::streamWrite(ss, tInt);
