@@ -14,7 +14,7 @@
 #include <RDGeneral/Exceptions.h>
 #include "point.h"
 #include <fstream>
-#include <boost/cstdint.hpp>
+#include <cstdint>
 
 #define OFFSET_TOL 1.e-8
 #define SPACING_TOL 1.e-8
@@ -311,9 +311,9 @@ UniformGrid3D &UniformGrid3D::operator-=(const UniformGrid3D &other) {
 std::string UniformGrid3D::toString() const {
   std::stringstream ss(std::ios_base::binary | std::ios_base::out |
                        std::ios_base::in);
-  boost::int32_t tVers = ci_GRIDPICKLE_VERSION * -1;
+  std::int32_t tVers = ci_GRIDPICKLE_VERSION * -1;
   streamWrite(ss, tVers);
-  boost::uint32_t tInt;
+  std::uint32_t tInt;
   tInt = d_numX;
   streamWrite(ss, tInt);
   tInt = d_numY;
@@ -326,7 +326,7 @@ std::string UniformGrid3D::toString() const {
   streamWrite(ss, d_offSet.z);
 
   std::string storePkl = dp_storage->toString();
-  boost::uint32_t pklSz = storePkl.size();
+  std::uint32_t pklSz = storePkl.size();
   streamWrite(ss, pklSz);
   ss.write(storePkl.c_str(), pklSz * sizeof(char));
 
@@ -337,14 +337,14 @@ void UniformGrid3D::initFromText(const char *pkl, const unsigned int length) {
   std::stringstream ss(std::ios_base::binary | std::ios_base::in |
                        std::ios_base::out);
   ss.write(pkl, length);
-  boost::int32_t tVers;
+  std::int32_t tVers;
   streamRead(ss, tVers);
   tVers *= -1;
   if (tVers == 0x1) {
   } else {
     throw ValueErrorException("bad version in UniformGrid3D pickle");
   }
-  boost::uint32_t tInt;
+  std::uint32_t tInt;
   streamRead(ss, tInt);
   d_numX = tInt;
   streamRead(ss, tInt);
@@ -358,7 +358,7 @@ void UniformGrid3D::initFromText(const char *pkl, const unsigned int length) {
   streamRead(ss, oZ);
   d_offSet = Point3D(oX, oY, oZ);
 
-  boost::uint32_t pklSz;
+  std::uint32_t pklSz;
   streamRead(ss, pklSz);
   auto *buff = new char[pklSz];
   ss.read(buff, pklSz * sizeof(char));
