@@ -385,18 +385,18 @@ class RDKIT_GRAPHMOL_EXPORT Atom : public RDProps {
 
   bool df_isAromatic;
   bool df_noImplicit;
-  boost::uint8_t d_numExplicitHs;
-  boost::int8_t d_formalCharge;
-  boost::uint8_t d_atomicNum;
+  std::uint8_t d_numExplicitHs;
+  std::int8_t d_formalCharge;
+  std::uint8_t d_atomicNum;
   // NOTE that these cannot be signed, they are calculated using
   // a lazy scheme and are initialized to -1 to indicate that the
   // calculation has not yet been done.
-  boost::int8_t d_implicitValence, d_explicitValence;
-  boost::uint8_t d_numRadicalElectrons;
-  boost::uint8_t d_chiralTag;
-  boost::uint8_t d_hybrid;
+  std::int8_t d_implicitValence, d_explicitValence;
+  std::uint8_t d_numRadicalElectrons;
+  std::uint8_t d_chiralTag;
+  std::uint8_t d_hybrid;
 
-  boost::uint16_t d_isotope;
+  std::uint16_t d_isotope;
   atomindex_t d_index;
 
   ROMol *dp_mol;
