@@ -39,10 +39,10 @@ class RDKIT_CHEMREACTIONS_EXPORT ReactionPicklerException : public std::exceptio
 //! handles pickling (serializing) reactions
 class RDKIT_CHEMREACTIONS_EXPORT ReactionPickler {
  public:
-  static const boost::int32_t versionMajor; //!< mark the pickle version
-  static const boost::int32_t versionMinor; //!< mark the pickle version
-  static const boost::int32_t versionPatch; //!< mark the pickle version
-  static const boost::int32_t endianId;  //! mark the endian-ness of the pickle
+  static const std::int32_t versionMajor; //!< mark the pickle version
+  static const std::int32_t versionMinor; //!< mark the pickle version
+  static const std::int32_t versionPatch; //!< mark the pickle version
+  static const std::int32_t endianId;  //! mark the endian-ness of the pickle
 
   //! the pickle format is tagged using these tags:
   //! NOTE: if you add to this list, be sure to put new entries AT THE BOTTOM,
