@@ -7,28 +7,32 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
+#include <RDGeneral/export.h>
 #pragma once
 #include <vector>
 #include <string>
 #include <stdexcept>
 #include "../RDKitBase.h"
 #include "Graph.h"
-#ifndef RDKIT_WRAP_DECL
-#define RDKIT_WRAP_DECL
-#endif
 
 namespace RDKit {
 struct MCSParameters;
 
-struct MCSAtomCompareParameters {
+struct RDKIT_FMCS_EXPORT MCSAtomCompareParameters {
   bool MatchValences;
   bool MatchChiralTag;
+  bool MatchFormalCharge;
+  bool RingMatchesRingOnly;
 
  public:
-  MCSAtomCompareParameters() : MatchValences(false), MatchChiralTag(false) {}
+  MCSAtomCompareParameters()
+      : MatchValences(false),
+        MatchChiralTag(false),
+        MatchFormalCharge(false),
+        RingMatchesRingOnly(false) {}
 };
 
-struct MCSBondCompareParameters {
+struct RDKIT_FMCS_EXPORT MCSBondCompareParameters {
   bool RingMatchesRingOnly;
   bool CompleteRingsOnly;
   bool MatchStereo;
@@ -54,32 +58,31 @@ typedef bool (*MCSBondCompareFunction)(const MCSBondCompareParameters& p,
                                        void* userData);
 
 // Some predefined functors:
-RDKIT_WRAP_DECL bool MCSAtomCompareAny(const MCSAtomCompareParameters& p, const ROMol& mol1,
-                       unsigned int atom1, const ROMol& mol2,
-                       unsigned int atom2, void* userData);
+RDKIT_FMCS_EXPORT bool MCSAtomCompareAny(const MCSAtomCompareParameters& p,
+                                         const ROMol& mol1, unsigned int atom1,
+                                         const ROMol& mol2, unsigned int atom2,
+                                         void* userData);
 
-RDKIT_WRAP_DECL bool MCSAtomCompareElements(const MCSAtomCompareParameters& p,
-                            const ROMol& mol1, unsigned int atom1,
-                            const ROMol& mol2, unsigned int atom2,
-                            void* userData);
-RDKIT_WRAP_DECL bool MCSAtomCompareIsotopes(const MCSAtomCompareParameters& p,
-                            const ROMol& mol1, unsigned int atom1,
-                            const ROMol& mol2, unsigned int atom2,
-                            void* userData);
+RDKIT_FMCS_EXPORT bool MCSAtomCompareElements(
+    const MCSAtomCompareParameters& p, const ROMol& mol1, unsigned int atom1,
+    const ROMol& mol2, unsigned int atom2, void* userData);
+RDKIT_FMCS_EXPORT bool MCSAtomCompareIsotopes(
+    const MCSAtomCompareParameters& p, const ROMol& mol1, unsigned int atom1,
+    const ROMol& mol2, unsigned int atom2, void* userData);
 
-RDKIT_WRAP_DECL bool MCSBondCompareAny(const MCSBondCompareParameters& p, const ROMol& mol1,
-                       unsigned int bond1, const ROMol& mol2,
-                       unsigned int bond2, void* userData);
-RDKIT_WRAP_DECL bool MCSBondCompareOrder(const MCSBondCompareParameters& p, const ROMol& mol1,
-                         unsigned int bond1, const ROMol& mol2,
-                         unsigned int bond2,
-                         void* userData);  // ignore Aromatization
-RDKIT_WRAP_DECL bool MCSBondCompareOrderExact(const MCSBondCompareParameters& p,
-                              const ROMol& mol1, unsigned int bond1,
-                              const ROMol& mol2, unsigned int bond2,
-                              void* userData);
+RDKIT_FMCS_EXPORT bool MCSBondCompareAny(const MCSBondCompareParameters& p,
+                                         const ROMol& mol1, unsigned int bond1,
+                                         const ROMol& mol2, unsigned int bond2,
+                                         void* userData);
+RDKIT_FMCS_EXPORT bool MCSBondCompareOrder(
+    const MCSBondCompareParameters& p, const ROMol& mol1, unsigned int bond1,
+    const ROMol& mol2, unsigned int bond2,
+    void* userData);  // ignore Aromatization
+RDKIT_FMCS_EXPORT bool MCSBondCompareOrderExact(
+    const MCSBondCompareParameters& p, const ROMol& mol1, unsigned int bond1,
+    const ROMol& mol2, unsigned int bond2, void* userData);
 
-struct MCSProgressData {
+struct RDKIT_FMCS_EXPORT MCSProgressData {
   unsigned NumAtoms;
   unsigned NumBonds;
   unsigned SeedProcessed;
@@ -91,10 +94,11 @@ struct MCSProgressData {
 typedef bool (*MCSProgressCallback)(const MCSProgressData& stat,
                                     const MCSParameters& params,
                                     void* userData);
-bool MCSProgressCallbackTimeout(const MCSProgressData& stat,
-                                const MCSParameters& params, void* userData);
+RDKIT_FMCS_EXPORT bool MCSProgressCallbackTimeout(const MCSProgressData& stat,
+                                                  const MCSParameters& params,
+                                                  void* userData);
 
-struct MCSParameters {
+struct RDKIT_FMCS_EXPORT MCSParameters {
   bool MaximizeBonds;
   double Threshold;
   unsigned Timeout;  // in seconds
@@ -119,13 +123,13 @@ struct MCSParameters {
         AtomTyper(MCSAtomCompareElements),
         BondTyper(MCSBondCompareOrder),
         CompareFunctionsUserData(0),
-        ProgressCallback(MCSProgressCallbackTimeout),
+        ProgressCallback(0),
         ProgressCallbackUserData(0),
         FinalMatchChecker(0),
         InitialSeed("") {}
 };
 
-struct MCSResult {
+struct RDKIT_FMCS_EXPORT MCSResult {
   unsigned NumAtoms;
   unsigned NumBonds;
   std::string SmartsString;
@@ -136,12 +140,13 @@ struct MCSResult {
   bool isCompleted() const { return !Canceled; }
 };
 
-void parseMCSParametersJSON(const char* json, MCSParameters* params);
+RDKIT_FMCS_EXPORT void parseMCSParametersJSON(const char* json,
+                                              MCSParameters* params);
 
-MCSResult findMCS(const std::vector<ROMOL_SPTR>& mols,
-                  const MCSParameters* params = 0);
-MCSResult findMCS_P(const std::vector<ROMOL_SPTR>& mols,
-                    const char* params_json);
+RDKIT_FMCS_EXPORT MCSResult findMCS(const std::vector<ROMOL_SPTR>& mols,
+                                    const MCSParameters* params = 0);
+RDKIT_FMCS_EXPORT MCSResult findMCS_P(const std::vector<ROMOL_SPTR>& mols,
+                                      const char* params_json);
 
 typedef enum {
   AtomCompareAny,
@@ -153,12 +158,12 @@ typedef enum {
   BondCompareOrder,
   BondCompareOrderExact
 } BondComparator;
-MCSResult findMCS(const std::vector<ROMOL_SPTR>& mols, bool maximizeBonds,
-                  double threshold = 1.0, unsigned timeout = 3600,
-                  bool verbose = false, bool matchValences = false,
-                  bool ringMatchesRingOnly = false,
-                  bool completeRingsOnly = false, bool matchChiralTag = false,
-                  AtomComparator atomComp = AtomCompareElements,
-                  BondComparator bondComp = BondCompareOrder);
+RDKIT_FMCS_EXPORT MCSResult
+findMCS(const std::vector<ROMOL_SPTR>& mols, bool maximizeBonds,
+        double threshold = 1.0, unsigned timeout = 3600, bool verbose = false,
+        bool matchValences = false, bool ringMatchesRingOnly = false,
+        bool completeRingsOnly = false, bool matchChiralTag = false,
+        AtomComparator atomComp = AtomCompareElements,
+        BondComparator bondComp = BondCompareOrder);
 
 }  // namespace RDKit
