@@ -7,6 +7,7 @@
 //  which is included in the file license.txt, found at the root
 //  of the RDKit source tree.
 //
+#include <RDGeneral/export.h>
 #pragma once
 #include <vector>
 #include "FMCS.h"
@@ -19,7 +20,7 @@ typedef std::vector<std::pair<FMCS::Graph::vertex_descriptor,
                               FMCS::Graph::vertex_descriptor> > match_V_t;
 const unsigned int NotSet = (unsigned int)-1;
 
-bool SubstructMatchCustomTable(
+RDKIT_FMCS_EXPORT bool SubstructMatchCustomTable(
     const FMCS::Graph& target, const ROMol& target_mol,
     const FMCS::Graph& query,
     const ROMol& querySrc  // seed and full source query molecules
@@ -29,7 +30,7 @@ bool SubstructMatchCustomTable(
     ,
     match_V_t* match = 0);
 
-bool SubstructMatchCustom(
+RDKIT_FMCS_EXPORT bool SubstructMatchCustom(
     const FMCS::Graph& target, const ROMol& mol, const FMCS::Graph& query,
     const ROMol& querySrc  // seed and full source query molecules
     ,
