@@ -1,4 +1,3 @@
-// $Id: testFMCS_Unit.cpp $
 //
 //  Copyright (c) 2014, Novartis Institutes for BioMedical Research Inc.
 //  All rights reserved.
@@ -30,7 +29,8 @@
 // (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
-#ifdef WIN32
+#ifdef _WIN32
+#include <RDGeneral/test.h>
 #include <Windows.h>
 #else
 #include <unistd.h>
@@ -71,7 +71,7 @@ void printTime() {
 
 std::string getSmilesOnly(
     const char* smiles,
-    std::string* id = 0) {  // remove label, because RDKit parse FAILED
+    std::string* id = nullptr) {  // remove label, because RDKit parse FAILED
   const char* sp = strchr(smiles, ' ');
   unsigned n = (sp ? sp - smiles + 1 : strlen(smiles));
   if (id) *id = std::string(smiles + n);
@@ -90,9 +90,9 @@ void test1Basics() {
       "CC1CCC(N)CC1", "CC1CC(C)CC(C)C1",  // OK test.sdf
   };
 
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++) {
+  for (auto& i : smi) {
     std::string id;
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i], &id))));
+    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i, &id))));
   }
   t0 = nanoClock();
   MCSResult res = findMCS(mols);
@@ -130,8 +130,7 @@ void test32() {
       "CHEMBL1334715",
       // 31 33 0.35 sec MCS: CCN(CC)c1ccc(cc1NC(=O)C=Cc1ccccc1)S(=O)(=O)N1CCOCC1
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   t0 = nanoClock();
   MCSResult res = findMCS(mols);
   std::cout << "MCS: " << res.SmartsString << " " << res.NumAtoms << " atoms, "
@@ -161,8 +160,7 @@ void test190() {
       //# 19 21 1.37 sec MCS: CC(=O)Nc1cccc(c1)-c1nc2ccccc2o1
       //  19 21 2.36 sec MCS: CC(=O)Nc1cccc(c1)-c1nc2ccccc2o1 19 atoms, 21 bonds
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   t0 = nanoClock();
   MCSResult res = findMCS(mols);
   std::cout << "MCS: " << res.SmartsString << " " << res.NumAtoms << " atoms, "
@@ -197,8 +195,7 @@ void test45() {
       "CHEMBL359567",
       "CCCc1c(OC)ccc2nc3c(c(CC)c21)Cn1c-3cc2c(c1=O)COC(=O)C2(O)CC CHEMBL373316",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   t0 = nanoClock();
   MCSResult res = findMCS(mols);
   std::cout << "MCS: " << res.SmartsString << " " << res.NumAtoms << " atoms, "
@@ -227,8 +224,7 @@ void test3() {
       "CC1(C)NC(C)(C)CC(NC(=O)Cc2ccccc2)C1 CHEMBL1703640",
       //# 3 . 1 14 14 0.08 sec MCS: CCCCNC(=O)Cc1ccccc1
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   t0 = nanoClock();
   MCSResult res = findMCS(mols);
   std::cout << "MCS: " << res.SmartsString << " " << res.NumAtoms << " atoms, "
@@ -249,9 +245,9 @@ void testRing1() {
       //      original molecule
       "COCc1cnc(C(=O)OC(C)C)c2[nH]ccc(Oc4ccc(Cl)cc4)cccc12",  // ring 3 removed
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
+  for (auto& i : smi)
     mols.push_back(
-        ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));  // with RING INFO
+        ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));  // with RING INFO
 
   MCSParameters p;
   p.BondCompareParameters.RingMatchesRingOnly = true;
@@ -362,8 +358,7 @@ void testThreshold() {
       "CCC", "CCCO", "CCCN", "CC",
       //        "CCC", "CC", //th=0.5
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   findMCS(mols);
   MCSParameters p;
   p.Threshold = 0.7;
@@ -413,8 +408,7 @@ void test330() {
       //# 330 F  42 41 30.93 sec MCS:
       //[#6]-[#6](-[#7]-[#6](-[#6](-[#6])-[#7]-[#6](-[#6](-[#6])-[#7]-[#6](-[#6](-[#6]-[#6]-[#6])-[#7]-[#6](-[#6](-[#6])-[#7]-[#6](-[#6])=[#8])=[#8])=[#8])=[#8])=[#8])-[#6](-[#7]-[#6](-[#6]-[#6](:[#6]):[#6]:[#6]:[#6]:[#6])-[#6](-[#8])=[#8])=[#8]
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   t0 = nanoClock();
   MCSResult res = findMCS(mols, &p);
@@ -443,8 +437,7 @@ void testTarget_no_10188_30149() {
       "COc1ccccc1Nc1ccc2c(c1)[nH]nc2-c1ccccc1 CHEMBL254443",
       "CN(C)CCNC(=O)c1cccc(-c2[nH]nc3cc(Nc4ccccc4Cl)ccc32)c1 CHEMBL198821",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   t0 = nanoClock();
   MCSResult res = findMCS(mols, &p);
@@ -482,8 +475,7 @@ void testTarget_no_10188_49064() {
       "Cn1c(=O)c(-c2c(Cl)cccc2Cl)cc2cnc(Nc3ccc(I)cc3)nc21",
       "CN1CCN(C(=O)c2ccc(Nc3ncc4cc(-c5c(Cl)cccc5Cl)c(=O)n(C)c4n3)cc2)CC1",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   t0 = nanoClock();
   MCSResult res = findMCS(mols, &p);
@@ -513,8 +505,7 @@ void testSegFault() {
       "O=C1CN(CCc2ccccc2)CCN1CCOC(c1ccc(F)cc1)c1ccc(F)cc1",
       "CN(CCOC(c1ccccc1)c1ccccc1)CCN(C)CCc1ccc(F)cc1",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   p.BondCompareParameters.RingMatchesRingOnly = true;
   p.BondCompareParameters.CompleteRingsOnly = true;
@@ -533,10 +524,10 @@ void testAtomCompareIsotopes() {
   std::cout << "\ntestAtomCompareIsotopes()\n";
   std::vector<ROMOL_SPTR> mols;
   const char* smi[] = {
-      "CC[13NH2]", "CC[13CH3]",
+      "CC[13NH2]",
+      "CC[13CH3]",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   p.AtomTyper = MCSAtomCompareIsotopes;
   t0 = nanoClock();
@@ -558,8 +549,7 @@ void testAtomCompareAnyAtom() {
       "c1ccccc1F",  // opt
       "c1ccccc1N",  // opt
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   p.AtomTyper = MCSAtomCompareAny;
   t0 = nanoClock();
@@ -582,8 +572,7 @@ void testAtomCompareAnyAtomBond() {
       "c1ccccc1F",  // opt
       "c1ccccc1N",  // opt
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   t0 = nanoClock();
   MCSParameters p;
   p.AtomTyper = MCSAtomCompareAny;
@@ -633,8 +622,7 @@ void testSimple() {
       "NC(C(C(C)C)NC(CNC(C3NC(=O)CC3)=O)=O)=O)CSSCC(C(O)=O)NC(=O)C3N("
       "CCC3O)C(=O)C(Cc3ccccc3)NC(=O)C(CSSC2)NC1=O CHEMBL1076370",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   p.BondCompareParameters.RingMatchesRingOnly = true;
   p.BondCompareParameters.CompleteRingsOnly = true;
@@ -663,8 +651,7 @@ void testSimpleFast() {
       "COCc1c(ncc2[nH]c3cccc(Oc4ccc(Cl)cc4)c3c12)C(=O)OC(C)C",
       "COCc1cnc(C(=O)OC(C)C)c2[nH]c3cc(Oc4ccc(Cl)cc4)ccc3c12",
   };
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++)
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i]))));
+  for (auto& i : smi) mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i))));
   MCSParameters p;
   t0 = nanoClock();
   MCSResult res = findMCS(mols, &p);
@@ -683,7 +670,7 @@ void compareChirality(const char* target, const char* query,
   ROMOL_SPTR target_ptr(SmilesToMol(target));
   ROMOL_SPTR query_ptr(SmartsToMol(query));
 
-  std::vector<std::pair<int, int> > vect;
+  std::vector<std::pair<int, int>> vect;
   bool sub_res = SubstructMatch(*target_ptr.get(), *query_ptr.get(), vect, true,
                                 useChirality);
 
@@ -774,8 +761,8 @@ void testJSONParameters() {
   BOOST_LOG(rdInfoLog) << "Testing FMCS testJSONParameters" << std::endl;
   MCSParameters pj;
 
-  parseMCSParametersJSON(NULL, &pj);
-  parseMCSParametersJSON("{}", NULL);
+  parseMCSParametersJSON(nullptr, &pj);
+  parseMCSParametersJSON("{}", nullptr);
 
   pj = MCSParameters();  // parsing of empty string keeps default values
   parseMCSParametersJSON("", &pj);
@@ -825,7 +812,7 @@ void testGithubIssue481() {
 
     BOOST_LOG(rdInfoLog) << "**** mols:" << s1 << "   " << s2 << "\n";
     //#688:
-    std::vector<std::pair<int, int> > vect;
+    std::vector<std::pair<int, int>> vect;
     ROMOL_SPTR mcs_mol(SmilesToMol("OCCl"));
     bool sub_res = SubstructMatch(*ptr2, *mcs_mol, vect, true, false);
     std::cout << "query=OCCl "
@@ -912,7 +899,7 @@ void testGithubIssue481() {
       BOOST_LOG(rdInfoLog) << "MCS: " << mcs_res.SmartsString << " "
                            << mcs_res.NumAtoms << " atoms, " << mcs_res.NumBonds
                            << " bonds\n";
-      std::vector<std::pair<int, int> > vect;
+      std::vector<std::pair<int, int>> vect;
       bool sub_res =
           SubstructMatch(*mols[1].get(), *mols[0].get(), vect, true, true);
       if (sub_res == false) {  // actualy == true & 4, 3 !!!
@@ -943,7 +930,7 @@ void testGithubIssue481() {
       BOOST_LOG(rdInfoLog) << "MCS: " << mcs_res.SmartsString << " "
                            << mcs_res.NumAtoms << " atoms, " << mcs_res.NumBonds
                            << " bonds\n";
-      std::vector<std::pair<int, int> > vect;
+      std::vector<std::pair<int, int>> vect;
       bool sub_res =
           SubstructMatch(*mols[1].get(), *mols[0].get(), vect, true, true);
       if (sub_res == false) {
@@ -964,9 +951,9 @@ void testInitialSeed() {
       "CC1CCC(N)CC1", "CC1CC(C)CC(C)C1",  // OK test.sdf
   };
 
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++) {
+  for (auto& i : smi) {
     std::string id;
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i], &id))));
+    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i, &id))));
   }
   MCSParameters p;
   p.InitialSeed = "CC";
@@ -991,14 +978,14 @@ void testInitialSeed2() {
   const char* initial_smarts = "CCNCCNcccccccnC1CC1";
   BOOST_LOG(rdInfoLog) << "initial_smarts: " << initial_smarts << std::endl;
 
-  for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++) {
+  for (auto& i : smi) {
     std::string id;
-    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(smi[i], &id))));
+    mols.push_back(ROMOL_SPTR(SmilesToMol(getSmilesOnly(i, &id))));
     std::auto_ptr<ROMol> seed(SmartsToMol(initial_smarts));
     MatchVectType match;
     bool matched = SubstructMatch(*mols.back(), *seed, match);
     BOOST_LOG(rdInfoLog) << (matched ? "RDKit MATCHED " : "RDKit DISmatched ")
-                         << smi[i] << std::endl;
+                         << i << std::endl;
   }
   MCSParameters p;
   p.InitialSeed = initial_smarts;
@@ -1037,12 +1024,13 @@ void testGithub631() {
   const char* smi[] = {
       // all examples derived from the bug report
       "CN(C)[C@@H]1CCCNC1",  // == MCS
-      "C1C=CCN1[C@@H]1CCCNC1", "Cc1cc2c(cc1C)C(=O)N([C@@H]1CCC(=O)NC1=O)C2=O",
+      "C1C=CCN1[C@@H]1CCCNC1",
+      "Cc1cc2c(cc1C)C(=O)N([C@@H]1CCC(=O)NC1=O)C2=O",
   };
 
   for (int pass = 0; pass < 2; ++pass, mols.clear())
-    for (size_t i = 0; i < sizeof(smi) / sizeof(smi[0]); i++) {
-      RWMol* m = SmilesToMol(getSmilesOnly(smi[i]));
+    for (auto& i : smi) {
+      RWMol* m = SmilesToMol(getSmilesOnly(i));
       TEST_ASSERT(m);
 
       if (0 == pass)
@@ -1056,9 +1044,10 @@ void testGithub631() {
         p.AtomCompareParameters.MatchChiralTag = false;
         //          p.Verbose = true;
         MCSResult res = findMCS(mols, &p);
-        BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " "
-                             << res.NumAtoms << " atoms, " << res.NumBonds
-                             << " bonds\n" << std::endl;
+        BOOST_LOG(rdInfoLog)
+            << "MCS: " << res.SmartsString << " " << res.NumAtoms << " atoms, "
+            << res.NumBonds << " bonds\n"
+            << std::endl;
         ;
 
         TEST_ASSERT(res.NumAtoms == mols[0]->getNumAtoms());
@@ -1071,9 +1060,10 @@ void testGithub631() {
         // p.BondCompareParameters.MatchStereo = useChirality;
         //        p.Verbose = true;
         MCSResult res = findMCS(mols, &p);
-        BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " "
-                             << res.NumAtoms << " atoms, " << res.NumBonds
-                             << " bonds\n" << std::endl;
+        BOOST_LOG(rdInfoLog)
+            << "MCS: " << res.SmartsString << " " << res.NumAtoms << " atoms, "
+            << res.NumBonds << " bonds\n"
+            << std::endl;
         ;
 
         TEST_ASSERT(res.NumAtoms == mols[0]->getNumAtoms());
@@ -1085,6 +1075,108 @@ void testGithub631() {
   BOOST_LOG(rdInfoLog) << "\tdone" << std::endl;
 }
 
+void testFormalChargeMatch() {
+  BOOST_LOG(rdInfoLog) << "-------------------------------------" << std::endl;
+  BOOST_LOG(rdInfoLog) << "Testing including formal charge in matches "
+                       << std::endl;
+  std::vector<ROMOL_SPTR> mols;
+  const char* smi[] = {"CCNC", "CCN(C)C", "CC[N+](C)C"};
+
+  for (auto& i : smi) {
+    RWMol* m = SmilesToMol(getSmilesOnly(i));
+    TEST_ASSERT(m);
+
+    mols.push_back(ROMOL_SPTR(m));
+  }
+  {
+    // by default charge is not used.
+    MCSParameters p;
+    MCSResult res = findMCS(mols, &p);
+    BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " " << res.NumAtoms
+                         << " atoms, " << res.NumBonds << " bonds\n"
+                         << std::endl;
+    ;
+
+    TEST_ASSERT(res.NumAtoms == 4);
+    TEST_ASSERT(res.NumBonds == 3);
+  }
+  {
+    // check charge
+    MCSParameters p;
+    p.AtomCompareParameters.MatchFormalCharge = true;
+    MCSResult res = findMCS(mols, &p);
+    BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " " << res.NumAtoms
+                         << " atoms, " << res.NumBonds << " bonds\n"
+                         << std::endl;
+    ;
+
+    TEST_ASSERT(res.NumAtoms == 2);
+    TEST_ASSERT(res.NumBonds == 1);
+  }
+
+  BOOST_LOG(rdInfoLog) << "============================================"
+                       << std::endl;
+  BOOST_LOG(rdInfoLog) << "\tdone" << std::endl;
+}
+
+void testGithub2034() {
+  BOOST_LOG(rdInfoLog) << "-------------------------------------" << std::endl;
+  BOOST_LOG(rdInfoLog) << "Testing Github #2034: add test for ring--non-ring "
+                          "matches at the atom level"
+                       << std::endl;
+  std::vector<ROMOL_SPTR> mols;
+  const char* smi[] = {"C1CC1N2CC2", "C1CC1N"};
+
+  for (auto& i : smi) {
+    auto m = SmilesToMol(getSmilesOnly(i));
+    TEST_ASSERT(m);
+
+    mols.push_back(ROMOL_SPTR(m));
+  }
+  {
+    // by default we're not doing ringMatchesRingOnly.
+    MCSResult res = findMCS(mols);
+    BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " " << res.NumAtoms
+                         << " atoms, " << res.NumBonds << " bonds\n"
+                         << std::endl;
+
+    TEST_ASSERT(res.NumAtoms == 4);
+    TEST_ASSERT(res.NumBonds == 4);
+  }
+
+  {
+    MCSParameters p;
+    p.AtomCompareParameters.RingMatchesRingOnly = true;
+    //          p.Verbose = true;
+    MCSResult res = findMCS(mols, &p);
+    BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " " << res.NumAtoms
+                         << " atoms, " << res.NumBonds << " bonds\n"
+                         << std::endl;
+
+    TEST_ASSERT(res.NumAtoms == 3);
+    TEST_ASSERT(res.NumBonds == 3);
+  }
+  {
+    // set it:
+    bool maximizeBonds = true, verbose = false, matchValences = false,
+         ringMatchesRingOnly = true;
+    double threshold = 1.0;
+    unsigned timeout = 3000;
+    MCSResult res = findMCS(mols, maximizeBonds, threshold, timeout, verbose,
+                            matchValences, ringMatchesRingOnly);
+    BOOST_LOG(rdInfoLog) << "MCS: " << res.SmartsString << " " << res.NumAtoms
+                         << " atoms, " << res.NumBonds << " bonds\n"
+                         << std::endl;
+
+    TEST_ASSERT(res.NumAtoms == 3);
+    TEST_ASSERT(res.NumBonds == 3);
+  }
+
+  BOOST_LOG(rdInfoLog) << "============================================"
+                       << std::endl;
+  BOOST_LOG(rdInfoLog) << "\tdone" << std::endl;
+}
+
 //====================================================================================================
 //====================================================================================================
 
@@ -1142,6 +1234,9 @@ int main(int argc, const char* argv[]) {
   testGithub631();
   //---
 
+  testFormalChargeMatch();
+  testGithub2034();
+
   unsigned long long t1 = nanoClock();
   double sec = double(t1 - T0) / 1000000.;
   printf("TOTAL Time elapsed %.2lf seconds\n", sec);
