@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2002-2013 greg landrum, Rational Discovery LLC
+//  Copyright (C) 2002-2019 greg landrum, Rational Discovery LLC
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -8,8 +8,8 @@
 //  of the RDKit source tree.
 //
 #include <RDGeneral/export.h>
-#ifndef _RD_MOLSUPPLIER_H
-#define _RD_MOLSUPPLIER_H
+#ifndef RD_MOLSUPPLIER_H
+#define RD_MOLSUPPLIER_H
 
 #include <RDGeneral/types.h>
 
@@ -106,6 +106,13 @@ class RDKIT_FILEPARSERS_EXPORT ForwardSDMolSupplier : public MolSupplier {
   virtual ROMol *next();
   virtual bool atEnd();
 
+  void setProcessPropertyLists(bool val) {
+    df_processPropertyLists = val;
+  }
+  bool getProcessPropertyLists() const {
+    return df_processPropertyLists;
+  }
+
  protected:
   virtual void checkForEnd();
   ROMol *_next();
@@ -113,6 +120,7 @@ class RDKIT_FILEPARSERS_EXPORT ForwardSDMolSupplier : public MolSupplier {
   bool df_end;
   int d_line;  // line number we are currently on
   bool df_sanitize, df_removeHs, df_strictParsing;
+  bool df_processPropertyLists;
 };
 
 // \brief a lazy supplier from an SD file
@@ -364,15 +372,26 @@ class RDKIT_FILEPARSERS_EXPORT PDBMolSupplier : public MolSupplier {
 #ifdef RDK_BUILD_COORDGEN_SUPPORT
 //! lazy file parser for MAE files
 class RDKIT_FILEPARSERS_EXPORT MaeMolSupplier : public MolSupplier {
+  /**
+   * Due to maeparser's shared_ptr<istream> Reader interface, MaeMolSupplier
+   * always requires taking ownership of the istream ptr, as the shared ptr will
+   * always clear it upon destruction.
+   */
+
  public:
   MaeMolSupplier() { init(); };
+
+  explicit MaeMolSupplier(std::shared_ptr<std::istream> inStream,
+                          bool sanitize = true, bool removeHs = true);
+
   explicit MaeMolSupplier(std::istream *inStream, bool takeOwnership = true,
                           bool sanitize = true, bool removeHs = true);
+
   explicit MaeMolSupplier(const std::string &fname, bool sanitize = true,
                           bool removeHs = true);
 
-  virtual ~MaeMolSupplier() {
-    if (df_owner && dp_inStream) delete dp_inStream;
+  virtual ~MaeMolSupplier(){
+      // The dp_sInStream shared_ptr will take care of cleaning up.
   };
 
   virtual void init();
@@ -384,6 +403,7 @@ class RDKIT_FILEPARSERS_EXPORT MaeMolSupplier : public MolSupplier {
   bool df_sanitize, df_removeHs;
   std::shared_ptr<schrodinger::mae::Reader> d_reader;
   std::shared_ptr<schrodinger::mae::Block> d_next_struct;
+  std::shared_ptr<std::istream> dp_sInStream;
 };
 #endif  // RDK_BUILD_COORDGEN_SUPPORT
 }  // namespace RDKit
