@@ -29,6 +29,7 @@
 // OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 //
 
+#include <RDGeneral/export.h>
 #ifndef __RD_FILTER_MATCHER_H__
 #define __RD_FILTER_MATCHER_H__
 #include <GraphMol/RDKitBase.h>
@@ -46,7 +47,7 @@ std::string getArgName(const boost::shared_ptr<FilterMatcherBase> &arg) {
 }
 
 namespace FilterMatchOps {
-class And : public FilterMatcherBase {
+class RDKIT_FILTERCATALOG_EXPORT And : public FilterMatcherBase {
   boost::shared_ptr<FilterMatcherBase> arg1;
   boost::shared_ptr<FilterMatcherBase> arg2;
 
@@ -58,7 +59,7 @@ class And : public FilterMatcherBase {
   //! True if arg1 and arg2 FilterMatchers are true
 
   And(const FilterMatcherBase &arg1, const FilterMatcherBase &arg2)
-      : FilterMatcherBase("And"), arg1(arg1.Clone()), arg2(arg2.Clone()) {}
+      : FilterMatcherBase("And"), arg1(arg1.copy()), arg2(arg2.copy()) {}
 
   And(const boost::shared_ptr<FilterMatcherBase> &arg1,
       const boost::shared_ptr<FilterMatcherBase> &arg2)
@@ -93,7 +94,7 @@ class And : public FilterMatcherBase {
     return false;
   }
 
-  boost::shared_ptr<FilterMatcherBase> Clone() const {
+  boost::shared_ptr<FilterMatcherBase> copy() const {
     return boost::shared_ptr<FilterMatcherBase>(new And(*this));
   }
 
@@ -111,7 +112,7 @@ class And : public FilterMatcherBase {
 #endif
 };
 
-class Or : public FilterMatcherBase {
+class RDKIT_FILTERCATALOG_EXPORT Or : public FilterMatcherBase {
   boost::shared_ptr<FilterMatcherBase> arg1;
   boost::shared_ptr<FilterMatcherBase> arg2;
 
@@ -122,7 +123,7 @@ class Or : public FilterMatcherBase {
   //! Constructs or Ander
   //! true if arg1 or arg2 are true
   Or(const FilterMatcherBase &arg1, const FilterMatcherBase &arg2)
-      : FilterMatcherBase("Or"), arg1(arg1.Clone()), arg2(arg2.Clone()) {}
+      : FilterMatcherBase("Or"), arg1(arg1.copy()), arg2(arg2.copy()) {}
 
   Or(const boost::shared_ptr<FilterMatcherBase> &arg1,
      const boost::shared_ptr<FilterMatcherBase> &arg2)
@@ -154,7 +155,7 @@ class Or : public FilterMatcherBase {
     return res1 || res2;
   }
 
-  boost::shared_ptr<FilterMatcherBase> Clone() const {
+  boost::shared_ptr<FilterMatcherBase> copy() const {
     return boost::shared_ptr<FilterMatcherBase>(new Or(*this));
   }
 
@@ -170,7 +171,7 @@ class Or : public FilterMatcherBase {
 #endif
 };
 
-class Not : public FilterMatcherBase {
+class RDKIT_FILTERCATALOG_EXPORT Not : public FilterMatcherBase {
   boost::shared_ptr<FilterMatcherBase> arg1;
 
  public:
@@ -182,7 +183,7 @@ class Not : public FilterMatcherBase {
   //  from getMatches since a false internal match matches
   //  nothing!
   Not(const FilterMatcherBase &arg1)
-      : FilterMatcherBase("Not"), arg1(arg1.Clone()) {}
+      : FilterMatcherBase("Not"), arg1(arg1.copy()) {}
 
   Not(const boost::shared_ptr<FilterMatcherBase> &arg1)
       : FilterMatcherBase("Not"), arg1(arg1) {}
@@ -208,7 +209,7 @@ class Not : public FilterMatcherBase {
     return !arg1->getMatches(mol, matchVect);
   }
 
-  boost::shared_ptr<FilterMatcherBase> Clone() const {
+  boost::shared_ptr<FilterMatcherBase> copy() const {
     return boost::shared_ptr<FilterMatcherBase>(new Not(*this));
   }
 
@@ -225,8 +226,8 @@ class Not : public FilterMatcherBase {
 };
 }
 
-extern const char *SMARTS_MATCH_NAME_DEFAULT;
-class SmartsMatcher : public FilterMatcherBase {
+RDKIT_FILTERCATALOG_EXPORT extern const char *SMARTS_MATCH_NAME_DEFAULT;
+class RDKIT_FILTERCATALOG_EXPORT SmartsMatcher : public FilterMatcherBase {
   ROMOL_SPTR d_pattern;
   unsigned int d_min_count;
   unsigned int d_max_count;
@@ -321,7 +322,7 @@ class SmartsMatcher : public FilterMatcherBase {
   virtual bool getMatches(const ROMol &mol,
                           std::vector<FilterMatch> &matchVect) const;
   virtual bool hasMatch(const ROMol &mol) const;
-  virtual boost::shared_ptr<FilterMatcherBase> Clone() const {
+  virtual boost::shared_ptr<FilterMatcherBase> copy() const {
     return boost::shared_ptr<FilterMatcherBase>(new SmartsMatcher(*this));
   }
 
@@ -367,7 +368,7 @@ class SmartsMatcher : public FilterMatcherBase {
 //
 //  which will return the SmartsMatcher FilterMatch only if no patterns
 //    in the exclusion list are found.
-class ExclusionList : public FilterMatcherBase {
+class RDKIT_FILTERCATALOG_EXPORT ExclusionList : public FilterMatcherBase {
   std::vector<boost::shared_ptr<FilterMatcherBase> > d_offPatterns;
 
  public:
@@ -403,7 +404,7 @@ class ExclusionList : public FilterMatcherBase {
 
   void addPattern(const FilterMatcherBase &base) {
     PRECONDITION(base.isValid(), "Invalid FilterMatcherBase");
-    d_offPatterns.push_back(base.Clone());
+    d_offPatterns.push_back(base.copy());
   }
 
   void setExclusionPatterns(
@@ -433,7 +434,7 @@ class ExclusionList : public FilterMatcherBase {
     return result;
   }
 
-  virtual boost::shared_ptr<FilterMatcherBase> Clone() const {
+  virtual boost::shared_ptr<FilterMatcherBase> copy() const {
     return boost::shared_ptr<FilterMatcherBase>(new ExclusionList(*this));
   }
 
@@ -449,6 +450,102 @@ class ExclusionList : public FilterMatcherBase {
 #endif
 };
 
+class RDKIT_FILTERCATALOG_EXPORT FilterHierarchyMatcher : public FilterMatcherBase {
+  std::vector<boost::shared_ptr<FilterHierarchyMatcher> > d_children;
+  boost::shared_ptr<FilterMatcherBase> d_matcher;
+  
+public:
+  // !Default Constructor for serialization
+  FilterHierarchyMatcher() : 
+    FilterMatcherBase(), 
+    d_matcher() {
+  }
+  //! Constructs a FilterHierarchyMatcher from a FilterMatchBase
+  //!  A FilterHierarchyMatcher is a tree hierarchy where to
+  //!  match a child node, one needs to match the parent first.
+  //!  For each branch, the lowest nodes are returned when
+  //!   getting the filter matches.
+  /*
+      \param matcher FilterMatcherBase to match this node against
+  */
+  FilterHierarchyMatcher(const FilterMatcherBase &matcher) :
+    FilterMatcherBase(), 
+    d_matcher(matcher.copy()) {
+  }
+  
+  //! Return the name for this node (from the underlying FilterMatcherBase)
+  virtual std::string getName() const {
+    if (d_matcher.get()) {
+      return d_matcher->getName();
+    }
+    return "FilterMatcherHierarchy root";
+  }
+
+  //! returns true if this node has a valid matcher
+  bool isValid() const {
+    return d_matcher->isValid();
+  }
+
+  //! Set a new FilterMatcherBase for this node
+  /*
+    \param matcher The new FilterMatcherBase
+  */
+  void setPattern(const FilterMatcherBase & matcher) {
+    PRECONDITION(matcher.isValid(), "Adding invalid patterns is not allowed.");
+    d_matcher = matcher.copy();
+    PRECONDITION(getName() == d_matcher->getName(), "Opps");
+  }
+
+  //! add a FilterHierarchy as a child.
+  //!  returns the FilterHierarchy pointer used in the tree (this is a
+  //!   shallow copy of the original)
+  /*
+    \param hierarchy The new FilterHierarchyMatcher child for this node
+  */
+  boost::shared_ptr<FilterHierarchyMatcher> addChild(
+      const FilterHierarchyMatcher &hierarchy) {
+    PRECONDITION(hierarchy.d_matcher.get() && hierarchy.d_matcher->isValid(),
+                 "Only one root node is allowed in a FilterHierarchyMatcher");
+    
+    d_children.push_back( boost::shared_ptr<FilterHierarchyMatcher>(
+        new FilterHierarchyMatcher(hierarchy) ));
+    return d_children.back();
+  }
+
+  //! returns the FilterMatches against the given molecule
+  /*
+    \param mol The molecule to match against
+    \param matches The vector of FilterMatch objects that match
+  */
+  virtual bool getMatches(const ROMol &mol, std::vector<FilterMatch> &matches) const;
+
+  //! Does this node match the molecule
+  /*
+    \param mol The molecule to match against
+  */
+  virtual bool hasMatch(const ROMol &mol) const {
+    std::vector<FilterMatch> temp;
+    return getMatches(mol, temp);
+  }
+
+  //! copys the FilterHierarchyMatcher into a FilterMatcherBase
+  virtual boost::shared_ptr<FilterMatcherBase> copy() const {
+    return boost::shared_ptr<FilterMatcherBase>(new FilterHierarchyMatcher(*this));
+  }
+ private:
+#ifdef RDK_USE_BOOST_SERIALIZATION
+  friend class boost::serialization::access;
+  template <class Archive>
+  void serialize(Archive &ar, const unsigned int version) {
+    RDUNUSED_PARAM(version);
+    ar &boost::serialization::base_object<FilterMatcherBase>(*this);
+    ar &d_children;
+    ar &d_matcher;
+  }
+#endif
+  
+};
+
 #ifdef RDK_USE_BOOST_SERIALIZATION
 // Register all known filter matcher types for serialization
 template <class Archive>
@@ -458,6 +555,7 @@ void registerFilterMatcherTypes(Archive &ar) {
   ar.register_type(static_cast<FilterMatchOps::Not *>(NULL));
   ar.register_type(static_cast<SmartsMatcher *>(NULL));
   ar.register_type(static_cast<ExclusionList *>(NULL));
+  ar.register_type(static_cast<FilterHierarchyMatcher *>(NULL));
 }
 #endif
 }
@@ -465,6 +563,7 @@ void registerFilterMatcherTypes(Archive &ar) {
 #ifdef RDK_USE_BOOST_SERIALIZATION
 BOOST_CLASS_VERSION(RDKit::SmartsMatcher, 1)
 BOOST_CLASS_VERSION(RDKit::ExclusionList, 1)
+BOOST_CLASS_VERSION(RDKit::FilterHierarchyMatcher, 1)
 #endif
 
 #endif
