@@ -45,14 +45,14 @@
 #include <map>
 #include <DataStructs/SparseIntVect.h>
 #include <DataStructs/ExplicitBitVect.h>
-#include <boost/cstdint.hpp>
+#include <cstdint>
 #include <GraphMol/Fingerprints/FingerprintUtil.h>
 
 namespace RDKit {
 class ROMol;
 namespace MorganFingerprints {
-typedef std::map<boost::uint32_t,
-                 std::vector<std::pair<boost::uint32_t, boost::uint32_t>>>
+typedef std::map<std::uint32_t,
+                 std::vector<std::pair<std::uint32_t, std::uint32_t>>>
     BitInfoMap;
 
 const std::string morganFingerprintVersion = "1.0.0";
@@ -100,10 +100,10 @@ const std::string morganFingerprintVersion = "1.0.0";
   responsible for calling delete on this.
 
 */
-RDKIT_FINGERPRINTS_EXPORT SparseIntVect<boost::uint32_t> *getFingerprint(
+RDKIT_FINGERPRINTS_EXPORT SparseIntVect<std::uint32_t> *getFingerprint(
     const ROMol &mol, unsigned int radius,
-    std::vector<boost::uint32_t> *invariants = 0,
-    const std::vector<boost::uint32_t> *fromAtoms = 0,
+    std::vector<std::uint32_t> *invariants = 0,
+    const std::vector<std::uint32_t> *fromAtoms = 0,
     bool useChirality = false, bool useBondTypes = true, bool useCounts = true,
     bool onlyNonzeroInvariants = false, BitInfoMap *atomsSettingBits = 0);
 
@@ -149,10 +149,10 @@ RDKIT_FINGERPRINTS_EXPORT SparseIntVect<boost::uint32_t> *getFingerprint(
   responsible for calling delete on this.
 
 */
-RDKIT_FINGERPRINTS_EXPORT SparseIntVect<boost::uint32_t> *getHashedFingerprint(
+RDKIT_FINGERPRINTS_EXPORT SparseIntVect<std::uint32_t> *getHashedFingerprint(
     const ROMol &mol, unsigned int radius, unsigned int nBits = 2048,
-    std::vector<boost::uint32_t> *invariants = 0,
-    const std::vector<boost::uint32_t> *fromAtoms = 0,
+    std::vector<std::uint32_t> *invariants = 0,
+    const std::vector<std::uint32_t> *fromAtoms = 0,
     bool useChirality = false, bool useBondTypes = true,
     bool onlyNonzeroInvariants = false, BitInfoMap *atomsSettingBits = 0);
 
@@ -190,8 +190,8 @@ RDKIT_FINGERPRINTS_EXPORT SparseIntVect<boost::uint32_t> *getHashedFingerprint(
 */
 RDKIT_FINGERPRINTS_EXPORT ExplicitBitVect *getFingerprintAsBitVect(
     const ROMol &mol, unsigned int radius, unsigned int nBits,
-    std::vector<boost::uint32_t> *invariants = 0,
-    const std::vector<boost::uint32_t> *fromAtoms = 0,
+    std::vector<std::uint32_t> *invariants = 0,
+    const std::vector<std::uint32_t> *fromAtoms = 0,
     bool useChirality = false, bool useBondTypes = true,
     bool onlyNonzeroInvariants = false, BitInfoMap *atomsSettingBits = 0);
 
