@@ -86,10 +86,12 @@ struct RDKIT_MOLDRAW2D_EXPORT MolDrawOptions {
   double additionalAtomLabelPadding;  // additional padding to leave around atom
                                       // labels. Expressed as a fraction of the
                                       // font size.
-  std::map<int, std::string> atomLabels;       // replacement labels for atoms
-  std::vector<std::vector<int> > atomRegions;  // regions
+  std::map<int, std::string> atomLabels;      // replacement labels for atoms
+  std::vector<std::vector<int>> atomRegions;  // regions
   DrawColour
       symbolColour;  // color to be used for the symbols and arrows in reactions
+  int bondLineWidth;  // if positive, this overrides the default line width
+                      // when drawing bonds
   std::vector<DrawColour> highlightColourPalette;  // defining 10 default colors
   // for highlighting atoms and bonds
   // or reactants in a reactions
@@ -113,7 +115,8 @@ struct RDKIT_MOLDRAW2D_EXPORT MolDrawOptions {
         multipleBondOffset(0.15),
         padding(0.05),
         additionalAtomLabelPadding(0.0),
-        symbolColour(0, 0, 0) {
+        symbolColour(0, 0, 0),
+        bondLineWidth(-1) {
     highlightColourPalette.push_back(
         DrawColour(1., 1., .67));                              // popcorn yellow
     highlightColourPalette.push_back(DrawColour(1., .8, .6));  // sand
@@ -150,7 +153,21 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
     sizes of the panels individual molecules are drawn in when
     \c drawMolecules() is called.
   */
-  MolDraw2D(int width, int height, int panelWidth = -1, int panelHeight = -1);
+  MolDraw2D(int width, int height, int panelWidth, int panelHeight)
+      : needs_scale_(true),
+        width_(width),
+        height_(height),
+        panel_width_(panelWidth > 0 ? panelWidth : width),
+        panel_height_(panelHeight > 0 ? panelHeight : height),
+        scale_(1.0),
+        x_trans_(0.0),
+        y_trans_(0.0),
+        x_offset_(0),
+        y_offset_(0),
+        font_size_(0.5),
+        curr_width_(2),
+        fill_polys_(true),
+        activeMolIdx_(-1) {}
 
   virtual ~MolDraw2D() {}
 
@@ -177,30 +194,30 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
       const ROMol &mol, const std::string &legend,
       const std::vector<int> *highlight_atoms,
       const std::vector<int> *highlight_bonds,
-      const std::map<int, DrawColour> *highlight_atom_map = NULL,
-      const std::map<int, DrawColour> *highlight_bond_map = NULL,
-      const std::map<int, double> *highlight_radii = NULL, int confId = -1);
+      const std::map<int, DrawColour> *highlight_atom_map = nullptr,
+      const std::map<int, DrawColour> *highlight_bond_map = nullptr,
+      const std::map<int, double> *highlight_radii = nullptr, int confId = -1);
 
   //! \overload
   virtual void drawMolecule(
-      const ROMol &mol, const std::vector<int> *highlight_atoms = NULL,
-      const std::map<int, DrawColour> *highlight_map = NULL,
-      const std::map<int, double> *highlight_radii = NULL, int confId = -1);
+      const ROMol &mol, const std::vector<int> *highlight_atoms = nullptr,
+      const std::map<int, DrawColour> *highlight_map = nullptr,
+      const std::map<int, double> *highlight_radii = nullptr, int confId = -1);
 
   //! \overload
   virtual void drawMolecule(
       const ROMol &mol, const std::string &legend,
-      const std::vector<int> *highlight_atoms = NULL,
-      const std::map<int, DrawColour> *highlight_map = NULL,
-      const std::map<int, double> *highlight_radii = NULL, int confId = -1);
+      const std::vector<int> *highlight_atoms = nullptr,
+      const std::map<int, DrawColour> *highlight_map = nullptr,
+      const std::map<int, double> *highlight_radii = nullptr, int confId = -1);
 
   //! \overload
   virtual void drawMolecule(
       const ROMol &mol, const std::vector<int> *highlight_atoms,
       const std::vector<int> *highlight_bonds,
-      const std::map<int, DrawColour> *highlight_atom_map = NULL,
-      const std::map<int, DrawColour> *highlight_bond_map = NULL,
-      const std::map<int, double> *highlight_radii = NULL, int confId = -1);
+      const std::map<int, DrawColour> *highlight_atom_map = nullptr,
+      const std::map<int, DrawColour> *highlight_bond_map = nullptr,
+      const std::map<int, double> *highlight_radii = nullptr, int confId = -1);
 
   //! draw multiple molecules in a grid
   /*!
@@ -230,13 +247,15 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
   */
   virtual void drawMolecules(
       const std::vector<ROMol *> &mols,
-      const std::vector<std::string> *legends = NULL,
-      const std::vector<std::vector<int> > *highlight_atoms = NULL,
-      const std::vector<std::vector<int> > *highlight_bonds = NULL,
-      const std::vector<std::map<int, DrawColour> > *highlight_atom_maps = NULL,
-      const std::vector<std::map<int, DrawColour> > *highlight_bond_maps = NULL,
-      const std::vector<std::map<int, double> > *highlight_radii = NULL,
-      const std::vector<int> *confIds = NULL);
+      const std::vector<std::string> *legends = nullptr,
+      const std::vector<std::vector<int>> *highlight_atoms = nullptr,
+      const std::vector<std::vector<int>> *highlight_bonds = nullptr,
+      const std::vector<std::map<int, DrawColour>> *highlight_atom_maps =
+          nullptr,
+      const std::vector<std::map<int, DrawColour>> *highlight_bond_maps =
+          nullptr,
+      const std::vector<std::map<int, double>> *highlight_radii = nullptr,
+      const std::vector<int> *confIds = nullptr);
 
   //! draw a ChemicalReaction
   /*!
@@ -252,8 +271,8 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
   */
   virtual void drawReaction(
       const ChemicalReaction &rxn, bool highlightByReactant = false,
-      const std::vector<DrawColour> *highlightColorsReactants = NULL,
-      const std::vector<int> *confIds = NULL);
+      const std::vector<DrawColour> *highlightColorsReactants = nullptr,
+      const std::vector<int> *confIds = nullptr);
 
   //! \name Transformations
   //@{
@@ -388,7 +407,7 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
     return at_cds_[activeMolIdx_];
   };
   //! returns the atomic symbols of the current molecule
-  const std::vector<std::pair<std::string, OrientType> > &atomSyms() const {
+  const std::vector<std::pair<std::string, OrientType>> &atomSyms() const {
     PRECONDITION(activeMolIdx_ >= 0, "no index");
     return atom_syms_[activeMolIdx_];
   };
@@ -411,9 +430,9 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
   DashPattern curr_dash_;
   MolDrawOptions options_;
 
-  std::vector<std::vector<Point2D> > at_cds_;  // from mol
-  std::vector<std::vector<int> > atomic_nums_;
-  std::vector<std::vector<std::pair<std::string, OrientType> > > atom_syms_;
+  std::vector<std::vector<Point2D>> at_cds_;  // from mol
+  std::vector<std::vector<int>> atomic_nums_;
+  std::vector<std::vector<std::pair<std::string, OrientType>>> atom_syms_;
   Point2D bbox_[2];
 
   // draw the char, with the bottom left hand corner at cds
@@ -421,9 +440,9 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
 
   // return a DrawColour based on the contents of highlight_atoms or
   // highlight_map, falling back to atomic number by default
-  DrawColour getColour(int atom_idx,
-                       const std::vector<int> *highlight_atoms = NULL,
-                       const std::map<int, DrawColour> *highlight_map = NULL);
+  DrawColour getColour(
+      int atom_idx, const std::vector<int> *highlight_atoms = nullptr,
+      const std::map<int, DrawColour> *highlight_map = nullptr);
   DrawColour getColourByAtomicNum(int atomic_num);
 
   void extractAtomCoords(const ROMol &mol, int confId, bool updateBBox);
@@ -431,26 +450,21 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
 
   virtual void drawLine(const Point2D &cds1, const Point2D &cds2,
                         const DrawColour &col1, const DrawColour &col2);
-  void drawBond(const ROMol &mol, const Bond* bond, int at1_idx,
-                int at2_idx, const std::vector<int> *highlight_atoms = NULL,
-                const std::map<int, DrawColour> *highlight_atom_map = NULL,
-                const std::vector<int> *highlight_bonds = NULL,
-                const std::map<int, DrawColour> *highlight_bond_map = NULL);
   void drawWedgedBond(const Point2D &cds1, const Point2D &cds2,
                       bool draw_dashed, const DrawColour &col1,
                       const DrawColour &col2);
   void drawAtomLabel(int atom_num,
-                     const std::vector<int> *highlight_atoms = NULL,
-                     const std::map<int, DrawColour> *highlight_map = NULL);
+                     const std::vector<int> *highlight_atoms = nullptr,
+                     const std::map<int, DrawColour> *highlight_map = nullptr);
   // cds1 and cds2 are 2 atoms in a ring.  Returns the perpendicular pointing
   // into
   // the ring.
-  Point2D bondInsideRing(const ROMol &mol, const Bond* bond,
+  Point2D bondInsideRing(const ROMol &mol, const Bond *bond,
                          const Point2D &cds1, const Point2D &cds2);
   // cds1 and cds2 are 2 atoms in a chain double bond.  Returns the
   // perpendicular
   // pointing into the inside of the bond
-  Point2D bondInsideDoubleBond(const ROMol &mol, const Bond* bond);
+  Point2D bondInsideDoubleBond(const ROMol &mol, const Bond *bond);
   // calculate normalised perpendicular to vector between two coords, such
   // that
   // it's inside the angle made between (1 and 2) and (2 and 3).
@@ -476,10 +490,16 @@ class RDKIT_MOLDRAW2D_EXPORT MolDraw2D {
       const std::map<int, double> *highlight_radii);
 
   virtual void highlightCloseContacts();
+  virtual void drawBond(
+      const ROMol &mol, const Bond *bond, int at1_idx, int at2_idx,
+      const std::vector<int> *highlight_atoms = nullptr,
+      const std::map<int, DrawColour> *highlight_atom_map = nullptr,
+      const std::vector<int> *highlight_bonds = nullptr,
+      const std::map<int, DrawColour> *highlight_bond_map = nullptr);
 
   // calculate normalised perpendicular to vector between two coords
   Point2D calcPerpendicular(const Point2D &cds1, const Point2D &cds2);
 };
-}
+}  // namespace RDKit
 
 #endif  // RDKITMOLDRAW2D_H
