@@ -38,6 +38,7 @@
 #include <GraphMol/ChemTransforms/ChemTransforms.h>
 #include <GraphMol/FMCS/FMCS.h>
 #include <boost/scoped_ptr.hpp>
+#include <boost/dynamic_bitset.hpp>
 #include <set>
 #include <utility>
 #include <vector>
@@ -86,7 +87,7 @@ bool hasDummy(const RWMol &core) {
   }
   return false;
 }
-}
+}  // namespace
 
 bool RGroupDecompositionParameters::prepareCore(RWMol &core,
                                                 const RWMol *alignCore) {
@@ -170,9 +171,6 @@ bool RGroupDecompositionParameters::prepareCore(RWMol &core,
   MolOps::AdjustQueryParameters adjustParams;
   adjustParams.makeDummiesQueries = true;
   adjustParams.adjustDegree = false;
-  adjustParams.adjustHeavyDegree = onlyMatchAtRGroups;
-  // if (onlyMatchAtRGroups)
-  //   adjustParams.adjustDegreeFlags |= MolOps::ADJUST_IGNOREHS;
   adjustQueryProperties(core, &adjustParams);
 
   for (auto &it : atomToLabel)
@@ -217,6 +215,8 @@ struct RGroupData {
 
     mols.push_back(newMol);
     std::string smi = MolToSmiles(*newMol, true);
+    // REVIEW: we probably shouldn't be using a set here... the merging of
+    // duplicates is likely not what we want
     smilesSet.insert(smi);
     if (!combinedMol.get()) {
       combinedMol = boost::shared_ptr<RWMol>(new RWMol(*mols[0].get()));
@@ -258,12 +258,13 @@ struct RGroupData {
       const {  // compute the canonical smiles for the attachments
     std::string s;
     for (const auto &it : smilesSet) {
+      if (s.length()) s += ".";
       s += it;
     }
     return s;
   }
 };
-}
+}  // namespace
 
 namespace {
 typedef boost::shared_ptr<RGroupData> RData;
@@ -328,7 +329,8 @@ double score(const std::vector<size_t> &permutation,
 #ifdef DEBUG
   std::cerr << "---------------------------------------------------"
             << std::endl;
-  std::cerr << "Scoring permutation " << std::endl;
+  std::cerr << "Scoring permutation "
+            << " num matches: " << matches.size() << std::endl;
 #endif
 
   for (int l : labels) {
@@ -337,16 +339,29 @@ double score(const std::vector<size_t> &permutation,
 #endif
     std::map<std::string, int> matchSet;
     std::map<std::set<int>, int> linkerMatchSet;
+    std::map<std::string, int> onlyH;
 
     for (size_t m = 0; m < permutation.size(); ++m) {  // for each molecule
       auto rg = matches[m][permutation[m]].rgroups.find(l);
       if (rg != matches[m][permutation[m]].rgroups.end()) {
 #ifdef DEBUG
-        std::cerr << " RGroup: " << rg->second->smiles;
+        std::cerr << "  combined: " << MolToSmiles(*rg->second->combinedMol)
+                  << std::endl;
+        std::cerr << " RGroup: " << rg->second->smiles << " "
+                  << rg->second->smiles.find_first_not_of("0123456789[]*H:.");
 #endif
-        matchSet[rg->second->smiles]+=1;
+        matchSet[rg->second->smiles] += 1;
+        // detect whether or not this is an H
+        if (rg->second->smiles.find_first_not_of("0123456789[]*H:.") >=
+            rg->second->smiles.length()) {
+          onlyH[rg->second->smiles] = 0;
+        } else {
+          onlyH[rg->second->smiles] = 1;
+        }
 #ifdef DEBUG
-        std::cerr << " score: " << matchSet[rg->second->smiles] << std::endl;
+        std::cerr << " " << rg->second->combinedMol->getNumAtoms(false)
+                  << " isH: " << onlyH[rg->second->smiles]
+                  << " score: " << matchSet[rg->second->smiles] << std::endl;
 #endif
         // XXX Use fragment counts to see if we are linking cycles?
         if (rg->second->smiles.find(".") == std::string::npos &&
@@ -365,14 +380,20 @@ double score(const std::vector<size_t> &permutation,
 
     for (std::map<std::string, int>::const_iterator it = matchSet.begin();
          it != matchSet.end(); ++it) {
-      
-      // if the rgroup is a hydrogens, only consider if the group is all
+#ifdef DEBUG
+      std::cerr << " equiv: " << it->first << " " << it->second << " "
+                << permutation.size() << std::endl;
+#endif
+
+      // if the rgroup is hydrogens, only consider if the group is all
       //  hydrogen, otherwise score based on the non hydrogens
-      if(it->first.find("[H]") != std::string::npos) {
-        if(static_cast<size_t>(it->second) == permutation.size())
+      if (onlyH[it->first]) {
+        if (static_cast<size_t>(it->second) == permutation.size()) {
           equivalentRGroupCount.push_back(static_cast<float>(it->second));
-        else
-          equivalentRGroupCount.push_back(it->second * 1.0/permutation.size()); // massively downweight hydrogens
+        } else {
+          // hydrogens in a mixed group don't contribute to the score
+          equivalentRGroupCount.push_back(0.0);
+        }
       } else {
         equivalentRGroupCount.push_back(static_cast<float>(it->second));
       }
@@ -385,8 +406,12 @@ double score(const std::vector<size_t> &permutation,
     //  each smaller set gets penalized (i+1) below
     //  1.0 is the perfect score
     for (size_t i = 0; i < equivalentRGroupCount.size(); ++i) {
-      tempScore *=
+      auto lscore =
           equivalentRGroupCount[i] / ((i + 1) * (double)matches.size());
+      if (lscore > 0) tempScore *= lscore * lscore;
+#ifdef DEBUG
+      std::cerr << "    lscore^2 " << i << ": " << lscore * lscore << std::endl;
+#endif
     }
 
     // overweight linkers with the same attachments points....
@@ -411,7 +436,7 @@ double score(const std::vector<size_t> &permutation,
       increment = tempScore;
     }
 
-    score *= increment * linkerIncrement;
+    score += increment * linkerIncrement;
 #ifdef DEBUG
     std::cerr << "Increment: " << increment
               << " Linker_Increment: " << linkerIncrement << std::endl;
@@ -423,7 +448,7 @@ double score(const std::vector<size_t> &permutation,
 
   return score;
 }
-}
+}  // namespace
 
 const unsigned int EMPTY_CORE_LABEL = -100000;
 
@@ -577,13 +602,13 @@ struct RGroupDecompData {
       auto atm = atoms.find(userLabel);
       if (atm == atoms.end()) continue;  // label not used in the rgroup
       Atom *atom = atm->second;
-      mappings[userLabel] = ++count;
-
+      mappings[userLabel] = userLabel;
+      if (count < userLabel) count = userLabel;
       if (atom->getAtomicNum() == 0) {  // add to existing dummy/rlabel
-        setRlabel(atom, count);
+        setRlabel(atom, userLabel);
       } else {  // adds new rlabel
         auto *newAt = new Atom(0);
-        setRlabel(newAt, count);
+        setRlabel(newAt, userLabel);
         atomsToAdd.push_back(std::make_pair(atom, newAt));
       }
     }
@@ -639,8 +664,6 @@ struct RGroupDecompData {
     }
 
     mol.setProp(done, true);
-    // std::cerr << "==> relabelling: " << mol.getProp<int>("idx") << " <++idx"
-    // << std::endl;
 
     std::vector<std::pair<Atom *, Atom *>> atomsToAdd;  // adds -R if necessary
 
@@ -806,7 +829,9 @@ int RGroupDecomposition::add(const ROMol &inmol) {
   // get the sidechains if possible
   //  Add hs for better symmeterization
   RWMol mol(inmol);
-  MolOps::addHs(mol);
+  bool explicitOnly = false;
+  bool addCoords = true;
+  MolOps::addHs(mol, explicitOnly, addCoords);
 
   int core_idx = 0;
   const RWMol *core = nullptr;
@@ -823,6 +848,52 @@ int RGroupDecomposition::add(const ROMol &inmol) {
                      useChirality);
     }
 
+    if (data->params.onlyMatchAtRGroups) {
+      // First find all the core atoms that have user
+      //  label and but their indices into core_atoms_with_user_labels
+      std::set<int> core_atoms_with_user_labels;
+
+      for (auto atom : coreIt->second.atoms()) {
+        if (atom->hasProp(RLABEL)) {
+          core_atoms_with_user_labels.insert(atom->getIdx());
+        }
+      }
+
+      std::vector<MatchVectType> tmatches_filtered;
+      for (auto &mv : tmatches) {
+        bool passes_filter = true;
+        boost::dynamic_bitset<> target_match_indices(mol.getNumAtoms());
+        for (auto &match : mv) {
+          target_match_indices[match.second] = 1;
+        }
+
+        for (auto &match : mv) {
+          const Atom *atm = mol.getAtomWithIdx(match.second);
+          // is this a labelled rgroup or not?
+          if (core_atoms_with_user_labels.find(match.first) ==
+              core_atoms_with_user_labels.end()) {
+            // nope... if any neighbor is not part of the substructure
+            //  make sure we are a hydrogen, otherwise, skip the match
+            for (const auto &nbri :
+                 boost::make_iterator_range(mol.getAtomNeighbors(atm))) {
+              const auto &nbr = mol[nbri];
+              if (nbr->getAtomicNum() != 1 &&
+                  !target_match_indices[nbr->getIdx()]) {
+                passes_filter = false;
+                break;
+              }
+            }
+          }
+          if (!passes_filter) break;
+        }
+
+        if (passes_filter) {
+          tmatches_filtered.push_back(mv);
+        }
+      }
+      tmatches = tmatches_filtered;
+    }
+
     if (!tmatches.size()) {
       continue;
     } else {
@@ -949,8 +1020,8 @@ int RGroupDecomposition::add(const ROMol &inmol) {
     }
   }
   if (potentialMatches.size() == 0) {
-    BOOST_LOG(rdWarningLog) << "No attachment points in side chains"
-                            << std::endl;
+    BOOST_LOG(rdWarningLog)
+        << "No attachment points in side chains" << std::endl;
 
     return -1;
   }
@@ -1066,7 +1137,7 @@ std::vector<unsigned int> Decomp(RGroupDecomposition &decomp,
   decomp.process();
   return unmatched;
 }
-}
+}  // namespace
 unsigned int RGroupDecompose(const std::vector<ROMOL_SPTR> &cores,
                              const std::vector<ROMOL_SPTR> &mols,
                              RGroupRows &rows,
@@ -1090,4 +1161,4 @@ unsigned int RGroupDecompose(const std::vector<ROMOL_SPTR> &cores,
   columns = decomp.getRGroupsAsColumns();
   return mols.size() - unmatched.size();
 }
-}
+}  // namespace RDKit
