@@ -28,7 +28,7 @@ typedef std::map<unsigned int, BondElectrons *> ConjBondMap;
 typedef std::map<unsigned int, AtomElectrons *> ConjAtomMap;
 typedef std::vector<ConjElectrons *> CEVect;
 typedef std::vector<CEVect2 *> CEVect3;
-typedef std::vector<boost::uint8_t> ConjFP;
+typedef std::vector<std::uint8_t> ConjFP;
 typedef boost::unordered_map<std::size_t, ConjElectrons *> CEMap;
 class RDKIT_GRAPHMOL_EXPORT ResonanceMolSupplier {
  public:
