@@ -54,7 +54,7 @@ namespace RDKit {
 namespace {
 int smarts_bond_parse(const std::string &inp, Bond *&bond) {
   void *scanner;
-  int res;
+  int res = 1;  // initialize with fail code
 
   TEST_ASSERT(!yysmarts_lex_init(&scanner));
   try {
@@ -69,11 +69,18 @@ int smarts_bond_parse(const std::string &inp, Bond *&bond) {
     throw;
   }
   yysmarts_lex_destroy(scanner);
+
+  if (res == 1) {
+    std::stringstream errout;
+    errout << "Failed parsing SMARTS '" << inp << "'";
+    throw SmilesParseException(errout.str());
+  }
+
   return res;
 }
 int smarts_atom_parse(const std::string &inp, Atom *&atom) {
   void *scanner;
-  int res;
+  int res = 1;  // initialize with fail code
 
   TEST_ASSERT(!yysmarts_lex_init(&scanner));
   try {
@@ -88,13 +95,20 @@ int smarts_atom_parse(const std::string &inp, Atom *&atom) {
     throw;
   }
   yysmarts_lex_destroy(scanner);
+
+  if (res == 1) {
+    std::stringstream errout;
+    errout << "Failed parsing SMARTS '" << inp << "'";
+    throw SmilesParseException(errout.str());
+  }
+
   return res;
 }
 
 int smiles_bond_parse(const std::string &inp, Bond *&bond) {
   std::list<unsigned int> branchPoints;
   void *scanner;
-  int res;
+  int res = 1;  // initialize with fail code
 
   TEST_ASSERT(!yysmiles_lex_init(&scanner));
   try {
@@ -109,12 +123,19 @@ int smiles_bond_parse(const std::string &inp, Bond *&bond) {
     throw;
   }
   yysmiles_lex_destroy(scanner);
+
+  if (res == 1) {
+    std::stringstream errout;
+    errout << "Failed parsing SMILES '" << inp << "'";
+    throw SmilesParseException(errout.str());
+  }
+
   return res;
 }
 int smiles_atom_parse(const std::string &inp, Atom *&atom) {
   std::list<unsigned int> branchPoints;
   void *scanner;
-  int res;
+  int res = 1;  // initialize with fail code
 
   TEST_ASSERT(!yysmiles_lex_init(&scanner));
   try {
@@ -129,12 +150,19 @@ int smiles_atom_parse(const std::string &inp, Atom *&atom) {
     throw;
   }
   yysmiles_lex_destroy(scanner);
+
+  if (res == 1) {
+    std::stringstream errout;
+    errout << "Failed parsing SMILES '" << inp << "'";
+    throw SmilesParseException(errout.str());
+  }
+
   return res;
 }
 int smiles_parse(const std::string &inp, std::vector<RDKit::RWMol *> &molVect) {
   std::list<unsigned int> branchPoints;
   void *scanner;
-  int res;
+  int res = 1;  // initialize with fail code
 
   TEST_ASSERT(!yysmiles_lex_init(&scanner));
   try {
@@ -149,6 +177,13 @@ int smiles_parse(const std::string &inp, std::vector<RDKit::RWMol *> &molVect) {
     throw;
   }
   yysmiles_lex_destroy(scanner);
+
+  if (res == 1) {
+    std::stringstream errout;
+    errout << "Failed parsing SMILES '" << inp << "'";
+    throw SmilesParseException(errout.str());
+  }
+
   if (!branchPoints.empty()) {
     throw SmilesParseException("extra open parentheses");
   }
@@ -156,7 +191,7 @@ int smiles_parse(const std::string &inp, std::vector<RDKit::RWMol *> &molVect) {
 }
 int smarts_parse(const std::string &inp, std::vector<RDKit::RWMol *> &molVect) {
   void *scanner;
-  int res;
+  int res = 1;  // initialize with fail code
   TEST_ASSERT(!yysmarts_lex_init(&scanner));
   try {
     size_t ltrim = setup_smarts_string(inp, scanner);
@@ -170,6 +205,13 @@ int smarts_parse(const std::string &inp, std::vector<RDKit::RWMol *> &molVect) {
     throw;
   }
   yysmarts_lex_destroy(scanner);
+
+  if (res == 1) {
+    std::stringstream errout;
+    errout << "Failed parsing SMARTS '" << inp << "'";
+    throw SmilesParseException(errout.str());
+  }
+
   return res;
 }
 
@@ -180,7 +222,7 @@ std::string labelRecursivePatterns(const std::string &sma) {
   std::list<SmaState> state;
   std::list<unsigned int> startRecurse;
   std::map<std::string, std::string> patterns;
-  std::string res = "";
+  std::string res;
 
   state.push_back(BASE);
 
@@ -230,14 +272,15 @@ RWMol *toMol(const std::string &inp,
              int func(const std::string &, std::vector<RDKit::RWMol *> &),
              const std::string &origInp) {
   // empty strings produce empty molecules:
-  if (inp == "") return new RWMol();
+  if (inp.empty()) return new RWMol();
   RWMol *res = nullptr;
   std::vector<RDKit::RWMol *> molVect;
   try {
     func(inp, molVect);
-    if (molVect.size() > 0) {
+    if (!molVect.empty()) {
       res = molVect[0];
       SmilesParseOps::CloseMolRings(res, false);
+      SmilesParseOps::SetUnspecifiedBondTypes(res);
       SmilesParseOps::AdjustAtomChiralityFlags(res);
       // No sense leaving this bookmark intact:
       if (res->hasAtomBookmark(ci_RIGHTMOST_ATOM)) {
@@ -269,7 +312,7 @@ RWMol *toMol(const std::string &inp,
 
 Atom *toAtom(const std::string &inp, int func(const std::string &, Atom *&)) {
   // empty strings produce empty molecules:
-  if (inp == "") return nullptr;
+  if (inp.empty()) return nullptr;
   Atom *res = nullptr;
   try {
     func(inp, res);
@@ -287,7 +330,7 @@ Atom *toAtom(const std::string &inp, int func(const std::string &, Atom *&)) {
 
 Bond *toBond(const std::string &inp, int func(const std::string &, Bond *&)) {
   // empty strings produce empty molecules:
-  if (inp == "") return nullptr;
+  if (inp.empty()) return nullptr;
   Bond *res = nullptr;
   try {
     func(inp, res);
@@ -321,7 +364,7 @@ void preprocessSmiles(const std::string &smiles,
     }
   }
 
-  if (lsmiles == "") {
+  if (lsmiles.empty()) {
     lsmiles = smiles;
   }
 
@@ -364,16 +407,17 @@ RWMol *SmilesToMol(const std::string &smiles,
                    const SmilesParserParams &params) {
   yysmiles_debug = params.debugParse;
 
-  std::string lsmiles = "", name = "", cxPart = "";
+  std::string lsmiles, name, cxPart;
   preprocessSmiles(smiles, params, lsmiles, name, cxPart);
   // strip any leading/trailing whitespace:
   // boost::trim_if(smi,boost::is_any_of(" \t\r\n"));
   RWMol *res = nullptr;
   res = toMol(lsmiles, smiles_parse, lsmiles);
 
-  if (res && params.allowCXSMILES && cxPart != "") {
+  if (res && params.allowCXSMILES && !cxPart.empty()) {
     std::string::const_iterator pos = cxPart.cbegin();
     SmilesParseOps::parseCXExtensions(*res, cxPart, pos);
+    res->setProp("_CXSMILES_Data", std::string(cxPart.cbegin(), pos));
     if (params.parseName && pos != cxPart.cend()) {
       std::string nmpart(pos, cxPart.cend());
       name = boost::trim_copy(nmpart);
@@ -396,9 +440,10 @@ RWMol *SmilesToMol(const std::string &smiles,
     bool cleanIt = true, force = true, flagPossible = true;
     MolOps::assignStereochemistry(*res, cleanIt, force, flagPossible);
   }
-  if (res && name != "") res->setProp(common_properties::_Name, name);
+  if (res && !name.empty()) res->setProp(common_properties::_Name, name);
   return res;
 };
+
 Atom *SmartsToAtom(const std::string &smiles) {
   yysmarts_debug = false;
 
