@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2002-2016 Greg Landrum and Rational Discovery LLC
+//  Copyright (C) 2002-2019 Greg Landrum and Rational Discovery LLC
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -293,7 +293,8 @@ std::string FragmentSmilesConstruct(
   std::list<unsigned int> ringClosuresToErase;
 
   Canon::canonicalizeFragment(mol, atomIdx, colors, ranks, molStack,
-                              bondsInPlay, bondSymbols, doIsomericSmiles, doRandom);
+                              bondsInPlay, bondSymbols, doIsomericSmiles,
+                              doRandom);
   Bond *bond = nullptr;
   BOOST_FOREACH (Canon::MolStackElem mSE, molStack) {
     switch (mSE.type) {
@@ -425,19 +426,18 @@ std::string MolToSmiles(const ROMol &mol, bool doIsomericSmiles, bool doKekule,
       tmol->debugMol(std::cout);
       std::cout << "----------------------------" << std::endl;
 #endif
-    
+
     // adding randomness without setting the rootedAtAtom
-    if (doRandom ) {
+    if (doRandom) {
       if (rootedAtAtom == -1) {
-        rootedAtAtom = std::rand() % mol.getNumAtoms(); 
+        rootedAtAtom = std::rand() % mol.getNumAtoms();
         // need to find an atom id between 0 and mol.getNumAtoms() exclusively
-        PRECONDITION(rootedAtAtom < 0 ||
-                   static_cast<unsigned int>(rootedAtAtom) < mol.getNumAtoms(),
-               "rootedAtomAtom must be less than the number of atoms");
+        PRECONDITION(rootedAtAtom < 0 || static_cast<unsigned int>(
+                                             rootedAtAtom) < mol.getNumAtoms(),
+                     "rootedAtomAtom must be less than the number of atoms");
       }
     }
 
-
     std::string res;
     unsigned int nAtoms = tmol->getNumAtoms();
     UINT_VECT ranks(nAtoms);
@@ -491,7 +491,8 @@ std::string MolToSmiles(const ROMol &mol, bool doIsomericSmiles, bool doKekule,
 
       subSmi = SmilesWrite::FragmentSmilesConstruct(
           *tmol, nextAtomIdx, colors, ranks, doKekule, canonical,
-          doIsomericSmiles, allBondsExplicit, allHsExplicit, doRandom ,  atomOrdering);
+          doIsomericSmiles, allBondsExplicit, allHsExplicit, doRandom,
+          atomOrdering);
 
       res += subSmi;
       colorIt = std::find(colors.begin(), colors.end(), Canon::WHITE_NODE);
@@ -543,6 +544,19 @@ std::string MolToSmiles(const ROMol &mol, bool doIsomericSmiles, bool doKekule,
   return result;
 }  // end of MolToSmiles()
 
+std::string MolToCXSmiles(const ROMol &mol, bool doIsomericSmiles,
+                          bool doKekule, int rootedAtAtom, bool canonical,
+                          bool allBondsExplicit, bool allHsExplicit,
+                          bool doRandom) {
+  auto res = MolToSmiles(mol, doIsomericSmiles, doKekule, rootedAtAtom,
+                         canonical, allBondsExplicit, allHsExplicit, doRandom);
+  auto cxext = SmilesWrite::getCXExtensions(mol);
+  if (cxext.length()) {
+    res += " " + cxext;
+  }
+  return res;
+}
+
 std::string MolFragmentToSmiles(const ROMol &mol,
                                 const std::vector<int> &atomsToUse,
                                 const std::vector<int> *bondsToUse,
@@ -703,4 +717,22 @@ std::string MolFragmentToSmiles(const ROMol &mol,
   mol.setProp(common_properties::_smilesAtomOutputOrder, atomOrdering, true);
   return res;
 }  // end of MolFragmentToSmiles()
+
+std::string MolFragmentToCXSmiles(const ROMol &mol,
+                                  const std::vector<int> &atomsToUse,
+                                  const std::vector<int> *bondsToUse,
+                                  const std::vector<std::string> *atomSymbols,
+                                  const std::vector<std::string> *bondSymbols,
+                                  bool doIsomericSmiles, bool doKekule,
+                                  int rootedAtAtom, bool canonical,
+                                  bool allBondsExplicit, bool allHsExplicit) {
+  auto res = MolFragmentToSmiles(
+      mol, atomsToUse, bondsToUse, atomSymbols, bondSymbols, doIsomericSmiles,
+      doKekule, rootedAtAtom, canonical, allBondsExplicit, allHsExplicit);
+  auto cxext = SmilesWrite::getCXExtensions(mol);
+  if (cxext.length()) {
+    res += " " + cxext;
+  }
+  return res;
+}
 }  // namespace RDKit
