@@ -1,5 +1,5 @@
 //
-//  Copyright (C) 2001-2018 Greg Landrum and Rational Discovery LLC
+//  Copyright (C) 2001-2019 Greg Landrum and Rational Discovery LLC
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -40,16 +40,12 @@ typedef std::map<unsigned int, QueryAtom::QUERYATOM_QUERY *> SUBQUERY_MAP;
 typedef struct {
   ResonanceMolSupplier &resMolSupplier;
   const ROMol &query;
-  bool uniquify;
-  bool recursionPossible;
-  bool useChirality;
-  bool useQueryQueryMatches;
-  unsigned int maxMatches;
+  const SubstructMatchParameters &params;
 } ResSubstructMatchHelperArgs_;
 
 void MatchSubqueries(const ROMol &mol, QueryAtom::QUERYATOM_QUERY *q,
-                     bool useChirality, SUBQUERY_MAP &subqueryMap,
-                     bool useQueryQueryMatches,
+                     const SubstructMatchParameters &params,
+                     SUBQUERY_MAP &subqueryMap,
                      std::vector<RecursiveStructureQuery *> &locked);
 
 bool matchCompare(const std::pair<int, int> &a, const std::pair<int, int> &b);
@@ -70,12 +66,12 @@ typedef std::list<
 class MolMatchFinalCheckFunctor {
  public:
   MolMatchFinalCheckFunctor(const ROMol &query, const ROMol &mol,
-                            bool useChirality)
-      : d_query(query), d_mol(mol), df_useChirality(useChirality){};
+                            const SubstructMatchParameters &ps)
+      : d_query(query), d_mol(mol), d_params(ps){};
   bool operator()(const boost::detail::node_id c1[],
                   const boost::detail::node_id c2[]) const {
     // std::cerr << "  check! " << df_useChirality << std::endl;
-    if (!df_useChirality) return true;
+    if (!d_params.useChirality) return true;
     // for (unsigned int i = 0; i < d_query.getNumAtoms(); ++i) {
     //   std::cerr << "    " << c1[i] << " " << c2[i] << std::endl;
     // }
@@ -205,20 +201,17 @@ class MolMatchFinalCheckFunctor {
  private:
   const ROMol &d_query;
   const ROMol &d_mol;
-  bool df_useChirality;
+  const SubstructMatchParameters &d_params;
 };
 
 class AtomLabelFunctor {
  public:
-  AtomLabelFunctor(const ROMol &query, const ROMol &mol, bool useChirality,
-                   bool useQueryQueryMatches)
-      : d_query(query),
-        d_mol(mol),
-        df_useChirality(useChirality),
-        df_useQueryQueryMatches(useQueryQueryMatches){};
+  AtomLabelFunctor(const ROMol &query, const ROMol &mol,
+                   const SubstructMatchParameters &ps)
+      : d_query(query), d_mol(mol), d_params(ps){};
   bool operator()(unsigned int i, unsigned int j) const {
     bool res = false;
-    if (df_useChirality) {
+    if (d_params.useChirality) {
       const Atom *qAt = d_query.getAtomWithIdx(i);
       if (qAt->getChiralTag() == Atom::CHI_TETRAHEDRAL_CW ||
           qAt->getChiralTag() == Atom::CHI_TETRAHEDRAL_CCW) {
@@ -228,26 +221,23 @@ class AtomLabelFunctor {
           return false;
       }
     }
-    res = atomCompat(d_query[i], d_mol[j], df_useQueryQueryMatches);
+    res = atomCompat(d_query[i], d_mol[j], d_params);
     return res;
   }
 
  private:
   const ROMol &d_query;
   const ROMol &d_mol;
-  bool df_useChirality;
-  bool df_useQueryQueryMatches;
+  const SubstructMatchParameters &d_params;
 };
 class BondLabelFunctor {
  public:
-  BondLabelFunctor(const ROMol &query, const ROMol &mol, bool useChirality,
-                   bool useQueryQueryMatches)
-      : d_query(query), d_mol(mol), df_useChirality(useChirality) {
-    RDUNUSED_PARAM(useQueryQueryMatches);
-  };
+  BondLabelFunctor(const ROMol &query, const ROMol &mol,
+                   const SubstructMatchParameters &ps)
+      : d_query(query), d_mol(mol), d_params(ps){};
   bool operator()(MolGraph::edge_descriptor i,
                   MolGraph::edge_descriptor j) const {
-    if (df_useChirality) {
+    if (d_params.useChirality) {
       const Bond *qBnd = d_query[i];
       if (qBnd->getBondType() == Bond::DOUBLE &&
           qBnd->getStereo() > Bond::STEREOANY) {
@@ -257,187 +247,65 @@ class BondLabelFunctor {
           return false;
       }
     }
-    bool res = bondCompat(d_query[i], d_mol[j]);
+    bool res = bondCompat(d_query[i], d_mol[j], d_params);
     return res;
   }
 
  private:
   const ROMol &d_query;
   const ROMol &d_mol;
-  bool df_useChirality;
-  // bool df_useQueryQueryMatches;
+  const SubstructMatchParameters &d_params;
 };
 void mergeMatchVect(std::vector<MatchVectType> &matches,
                     const std::vector<MatchVectType> &matchesTmp,
                     const ResSubstructMatchHelperArgs_ &args) {
   for (auto it = matchesTmp.begin();
-       (matches.size() < args.maxMatches) && (it != matchesTmp.end()); ++it) {
+       (matches.size() < args.params.maxMatches) && (it != matchesTmp.end());
+       ++it) {
     if ((std::find(matches.begin(), matches.end(), *it) == matches.end()) &&
-        (!args.uniquify || isToBeAddedToVector(matches, *it)))
+        (!args.params.uniquify || isToBeAddedToVector(matches, *it)))
       matches.push_back(*it);
   }
 };
 void ResSubstructMatchHelper_(const ResSubstructMatchHelperArgs_ &args,
                               std::vector<MatchVectType> *matches,
                               unsigned int bi, unsigned int ei) {
-  for (unsigned int i = bi; (matches->size() < args.maxMatches) && (i < ei);
-       ++i) {
+  for (unsigned int i = bi;
+       (matches->size() < args.params.maxMatches) && (i < ei); ++i) {
     ROMol *mol = args.resMolSupplier[i];
-    std::vector<MatchVectType> matchesTmp;
-    SubstructMatch(*mol, args.query, matchesTmp, args.uniquify,
-                   args.recursionPossible, args.useChirality,
-                   args.useQueryQueryMatches, args.maxMatches);
+    std::vector<MatchVectType> matchesTmp =
+        SubstructMatch(*mol, args.query, args.params);
     mergeMatchVect(*matches, matchesTmp, args);
     delete mol;
   }
 };
-}
-
-// ----------------------------------------------
-//
-// find one match
-//
-bool SubstructMatch(const ROMol &mol, const ROMol &query,
-                    MatchVectType &matchVect, bool recursionPossible,
-                    bool useChirality, bool useQueryQueryMatches) {
-  // std::cerr<<"begin match"<<std::endl;
-  std::vector<RecursiveStructureQuery *> locked;
-#ifdef RDK_THREADSAFE_SSS
-  locked.reserve(query.getNumAtoms());
-#endif
-  if (recursionPossible) {
-    ROMol::ConstAtomIterator atIt;
-    detail::SUBQUERY_MAP subqueryMap;
-    for (atIt = query.beginAtoms(); atIt != query.endAtoms(); atIt++) {
-      if ((*atIt)->getQuery()) {
-        detail::MatchSubqueries(mol, (*atIt)->getQuery(), useChirality,
-                                subqueryMap, useQueryQueryMatches, locked);
-      }
-    }
-  }
-  // std::cerr<<"main matching"<<std::endl;
-
-  matchVect.clear();
-  matchVect.resize(0);
-
-  detail::MolMatchFinalCheckFunctor matchChecker(query, mol, useChirality);
-  detail::AtomLabelFunctor atomLabeler(query, mol, useChirality,
-                                       useQueryQueryMatches);
-  detail::BondLabelFunctor bondLabeler(query, mol, useChirality,
-                                       useQueryQueryMatches);
-
-  detail::ssPairType match;
-#if 0
-    bool res=boost::ullmann(query.getTopology(),mol.getTopology(),
-                            atomLabeler,bondLabeler,match);
-#else
-  bool res = boost::vf2(query.getTopology(), mol.getTopology(), atomLabeler,
-                        bondLabeler, matchChecker, match);
-#endif
-  if (res) {
-    matchVect.resize(query.getNumAtoms());
-    for (detail::ssPairType::const_iterator iter = match.begin();
-         iter != match.end(); ++iter) {
-      matchVect[iter->first] = std::pair<int, int>(iter->first, iter->second);
-    }
-  }
-
-#ifdef RDK_THREADSAFE_SSS
-  if (recursionPossible) {
-    BOOST_FOREACH (RecursiveStructureQuery *v, locked)
-      v->d_mutex.unlock();
-  }
-#endif
-  return res;
-}
-
-bool SubstructMatch(const MolBundle &bundle, const ROMol &query,
-                    MatchVectType &matchVect, bool recursionPossible,
-                    bool useChirality, bool useQueryQueryMatches) {
-  bool res = false;
-  for (unsigned int i = 0; i < bundle.size() && !res; ++i) {
-    res = SubstructMatch(*bundle[i], query, matchVect, recursionPossible,
-                         useChirality, useQueryQueryMatches);
-  }
-  return res;
-}
-
-bool SubstructMatch(const ROMol &mol, const MolBundle &bundle,
-                    MatchVectType &matchVect, bool recursionPossible,
-                    bool useChirality, bool useQueryQueryMatches) {
-  bool res = false;
-  for (unsigned int i = 0; i < bundle.size() && !res; ++i) {
-    res = SubstructMatch(mol, *bundle[i], matchVect, recursionPossible,
-                         useChirality, useQueryQueryMatches);
-  }
-  return res;
-}
-
-bool SubstructMatch(const MolBundle &bundle, const MolBundle &qbundle,
-                    MatchVectType &matchVect, bool recursionPossible,
-                    bool useChirality, bool useQueryQueryMatches) {
-  bool res = false;
-  for (unsigned int i = 0; i < bundle.size() && !res; ++i) {
-    for (unsigned int j = 0; j < bundle.size() && !res; ++j) {
-      res =
-          SubstructMatch(*bundle[i], *qbundle[j], matchVect, recursionPossible,
-                         useChirality, useQueryQueryMatches);
-    }
-  }
-  return res;
-}
-// ----------------------------------------------
-//
-// find one match in ResonanceMolSupplier object
-//
-bool SubstructMatch(ResonanceMolSupplier &resMolSupplier, const ROMol &query,
-                    MatchVectType &matchVect, bool recursionPossible,
-                    bool useChirality, bool useQueryQueryMatches) {
-  bool match = false;
-  for (unsigned int i = 0; !match && (i < resMolSupplier.length()); ++i) {
-    ROMol *mol = resMolSupplier[i];
-    match = SubstructMatch(*mol, query, matchVect, recursionPossible,
-                           useChirality, useQueryQueryMatches);
-    delete mol;
-  }
-  return match;
-}
+}  // namespace detail
 
 // ----------------------------------------------
 //
 // find all matches
-//
-//  NOTE: this blows out the contents of matches
-//
-unsigned int SubstructMatch(const ROMol &mol, const ROMol &query,
-                            std::vector<MatchVectType> &matches, bool uniquify,
-                            bool recursionPossible, bool useChirality,
-                            bool useQueryQueryMatches,
-                            unsigned int maxMatches) {
+std::vector<MatchVectType> SubstructMatch(
+    const ROMol &mol, const ROMol &query,
+    const SubstructMatchParameters &params) {
   std::vector<RecursiveStructureQuery *> locked;
 #ifdef RDK_THREADSAFE_SSS
   locked.reserve(query.getNumAtoms());
 #endif
-  if (recursionPossible) {
+  if (params.recursionPossible) {
     detail::SUBQUERY_MAP subqueryMap;
     ROMol::ConstAtomIterator atIt;
     for (atIt = query.beginAtoms(); atIt != query.endAtoms(); atIt++) {
       if ((*atIt)->getQuery()) {
         // std::cerr<<"recurse from atom "<<(*atIt)->getIdx()<<std::endl;
-        detail::MatchSubqueries(mol, (*atIt)->getQuery(), useChirality,
-                                subqueryMap, useQueryQueryMatches, locked);
+        detail::MatchSubqueries(mol, (*atIt)->getQuery(), params, subqueryMap,
+                                locked);
       }
     }
   }
 
-  matches.clear();
-  matches.resize(0);
-
-  detail::AtomLabelFunctor atomLabeler(query, mol, useChirality,
-                                       useQueryQueryMatches);
-  detail::BondLabelFunctor bondLabeler(query, mol, useChirality,
-                                       useQueryQueryMatches);
-  detail::MolMatchFinalCheckFunctor matchChecker(query, mol, useChirality);
+  detail::AtomLabelFunctor atomLabeler(query, mol, params);
+  detail::BondLabelFunctor bondLabeler(query, mol, params);
+  detail::MolMatchFinalCheckFunctor matchChecker(query, mol, params);
 
   std::list<detail::ssPairType> pms;
 #if 0
@@ -446,9 +314,9 @@ unsigned int SubstructMatch(const ROMol &mol, const ROMol &query,
 #else
   bool found =
       boost::vf2_all(query.getTopology(), mol.getTopology(), atomLabeler,
-                     bondLabeler, matchChecker, pms, maxMatches);
+                     bondLabeler, matchChecker, pms, params.maxMatches);
 #endif
-  unsigned int res = 0;
+  std::vector<MatchVectType> matches;
   if (found) {
     unsigned int nQueryAtoms = query.getNumAtoms();
     matches.reserve(pms.size());
@@ -461,58 +329,47 @@ unsigned int SubstructMatch(const ROMol &mol, const ROMol &query,
       }
       matches.push_back(matchVect);
     }
-    if (uniquify) {
+    if (params.uniquify) {
       removeDuplicates(matches, mol.getNumAtoms());
     }
-    res = matches.size();
   }
 
 #ifdef RDK_THREADSAFE_SSS
-  if (recursionPossible) {
+  if (params.recursionPossible) {
     BOOST_FOREACH (RecursiveStructureQuery *v, locked)
       v->d_mutex.unlock();
   }
 #endif
-  return res;
+  return matches;
 }
 
-unsigned int SubstructMatch(const MolBundle &mol, const ROMol &query,
-                            std::vector<MatchVectType> &matches, bool uniquify,
-                            bool recursionPossible, bool useChirality,
-                            bool useQueryQueryMatches,
-                            unsigned int maxMatches) {
-  unsigned int res = 0;
-  for (unsigned int i = 0; i < mol.size() && !res; ++i) {
-    res = SubstructMatch(*mol[i], query, matches, uniquify, recursionPossible,
-                         useChirality, useQueryQueryMatches, maxMatches);
+std::vector<MatchVectType> SubstructMatch(
+    const MolBundle &bundle, const ROMol &query,
+    const SubstructMatchParameters &params) {
+  std::vector<MatchVectType> res;
+  for (unsigned int i = 0; i < bundle.size() && !res.size(); ++i) {
+    res = SubstructMatch(*bundle[i], query, params);
   }
   return res;
 }
 
-unsigned int SubstructMatch(const ROMol &mol, const MolBundle &query,
-                            std::vector<MatchVectType> &matches, bool uniquify,
-                            bool recursionPossible, bool useChirality,
-                            bool useQueryQueryMatches,
-                            unsigned int maxMatches) {
-  unsigned int res = 0;
-  for (unsigned int i = 0; i < query.size() && !res; ++i) {
-    res = SubstructMatch(mol, *query[i], matches, uniquify, recursionPossible,
-                         useChirality, useQueryQueryMatches, maxMatches);
+std::vector<MatchVectType> SubstructMatch(
+    const ROMol &mol, const MolBundle &query,
+    const SubstructMatchParameters &params) {
+  std::vector<MatchVectType> res;
+  for (unsigned int i = 0; i < query.size() && !res.size(); ++i) {
+    res = SubstructMatch(mol, *query[i], params);
   }
   return res;
 }
 
-unsigned int SubstructMatch(const MolBundle &mol, const MolBundle &query,
-                            std::vector<MatchVectType> &matches, bool uniquify,
-                            bool recursionPossible, bool useChirality,
-                            bool useQueryQueryMatches,
-                            unsigned int maxMatches) {
-  unsigned int res = 0;
-  for (unsigned int i = 0; i < mol.size() && !res; ++i) {
-    for (unsigned int j = 0; j < query.size() && !res; ++j) {
-      res = SubstructMatch(*mol[i], *query[j], matches, uniquify,
-                           recursionPossible, useChirality,
-                           useQueryQueryMatches, maxMatches);
+std::vector<MatchVectType> SubstructMatch(
+    const MolBundle &mol, const MolBundle &query,
+    const SubstructMatchParameters &params) {
+  std::vector<MatchVectType> res;
+  for (unsigned int i = 0; i < mol.size() && !res.size(); ++i) {
+    for (unsigned int j = 0; j < query.size() && !res.size(); ++j) {
+      res = SubstructMatch(*mol[i], *query[j], params);
     }
   }
   return res;
@@ -522,21 +379,14 @@ unsigned int SubstructMatch(const MolBundle &mol, const MolBundle &query,
 //
 // find all matches in a ResonanceMolSupplier object
 //
-//  NOTE: this blows out the contents of matches
 //
-unsigned int SubstructMatch(ResonanceMolSupplier &resMolSupplier,
-                            const ROMol &query,
-                            std::vector<MatchVectType> &matches, bool uniquify,
-                            bool recursionPossible, bool useChirality,
-                            bool useQueryQueryMatches, unsigned int maxMatches,
-                            int numThreads) {
-  matches.clear();
-  detail::ResSubstructMatchHelperArgs_ args = {
-      resMolSupplier,    query,        uniquify,
-      recursionPossible, useChirality, useQueryQueryMatches,
-      maxMatches};
+std::vector<MatchVectType> SubstructMatch(
+    ResonanceMolSupplier &resMolSupplier, const ROMol &query,
+    const SubstructMatchParameters &params) {
+  std::vector<MatchVectType> matches;
+  detail::ResSubstructMatchHelperArgs_ args = {resMolSupplier, query, params};
   unsigned int nt =
-      std::min(resMolSupplier.length(), getNumThreadsToUse(numThreads));
+      std::min(resMolSupplier.length(), getNumThreadsToUse(params.numThreads));
   if (nt == 1)
     detail::ResSubstructMatchHelper_(args, &matches, 0,
                                      resMolSupplier.length());
@@ -572,28 +422,25 @@ unsigned int SubstructMatch(ResonanceMolSupplier &resMolSupplier,
   }
 #endif
   std::sort(matches.begin(), matches.end(), detail::matchVectCompare);
-  return matches.size();
+  return matches;
 }
 
 namespace detail {
 unsigned int RecursiveMatcher(const ROMol &mol, const ROMol &query,
-                              std::vector<int> &matches, bool useChirality,
+                              std::vector<int> &matches,
                               SUBQUERY_MAP &subqueryMap,
-                              bool useQueryQueryMatches,
+                              const SubstructMatchParameters &params,
                               std::vector<RecursiveStructureQuery *> &locked) {
   ROMol::ConstAtomIterator atIt;
   for (atIt = query.beginAtoms(); atIt != query.endAtoms(); atIt++) {
     if ((*atIt)->getQuery()) {
-      MatchSubqueries(mol, (*atIt)->getQuery(), useChirality, subqueryMap,
-                      useQueryQueryMatches, locked);
+      MatchSubqueries(mol, (*atIt)->getQuery(), params, subqueryMap, locked);
     }
   }
 
-  detail::AtomLabelFunctor atomLabeler(query, mol, useChirality,
-                                       useQueryQueryMatches);
-  detail::BondLabelFunctor bondLabeler(query, mol, useChirality,
-                                       useQueryQueryMatches);
-  detail::MolMatchFinalCheckFunctor matchChecker(query, mol, useChirality);
+  detail::AtomLabelFunctor atomLabeler(query, mol, params);
+  detail::BondLabelFunctor bondLabeler(query, mol, params);
+  detail::MolMatchFinalCheckFunctor matchChecker(query, mol, params);
 
   matches.clear();
   matches.resize(0);
@@ -636,8 +483,8 @@ unsigned int RecursiveMatcher(const ROMol &mol, const ROMol &query,
 }
 
 void MatchSubqueries(const ROMol &mol, QueryAtom::QUERYATOM_QUERY *query,
-                     bool useChirality, SUBQUERY_MAP &subqueryMap,
-                     bool useQueryQueryMatches,
+                     const SubstructMatchParameters &params,
+                     SUBQUERY_MAP &subqueryMap,
                      std::vector<RecursiveStructureQuery *> &locked) {
   PRECONDITION(query, "bad query");
   // std::cout << "*-*-* MS: " << (int)query << std::endl;
@@ -670,9 +517,8 @@ void MatchSubqueries(const ROMol &mol, QueryAtom::QUERYATOM_QUERY *query,
       // in case we are reusing this query, clear its contents now.
       if (queryMol) {
         std::vector<int> matchStarts;
-        unsigned int res =
-            RecursiveMatcher(mol, *queryMol, matchStarts, useChirality,
-                             subqueryMap, useQueryQueryMatches, locked);
+        unsigned int res = RecursiveMatcher(mol, *queryMol, matchStarts,
+                                            subqueryMap, params, locked);
         if (res) {
           for (int &matchStart : matchStarts) {
             rsq->insert(matchStart);
@@ -695,8 +541,7 @@ void MatchSubqueries(const ROMol &mol, QueryAtom::QUERYATOM_QUERY *query,
   // std::endl;
   for (childIt = query->beginChildren(); childIt != query->endChildren();
        childIt++) {
-    MatchSubqueries(mol, childIt->get(), useChirality, subqueryMap,
-                    useQueryQueryMatches, locked);
+    MatchSubqueries(mol, childIt->get(), params, subqueryMap, locked);
   }
   // std::cout << "<<- back " << (int)query << std::endl;
 }
@@ -738,4 +583,4 @@ bool isToBeAddedToVector(std::vector<MatchVectType> &matches,
   return isToBeAdded;
 }
 }  // end of namespace detail
-}
+}  // namespace RDKit
