@@ -1,6 +1,5 @@
-// $Id$
 //
-//  Copyright (C) 2003-2010 Greg Landrum and Rational Discovery LLC
+//  Copyright (C) 2003-2019 Greg Landrum and Rational Discovery LLC
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -16,14 +15,14 @@
 
 namespace RDKit {
 
-bool atomCompat(const Atom* a1, const Atom* a2,
-                bool useQueryQueryMatches) {
+bool atomCompat(const Atom *a1, const Atom *a2,
+                const SubstructMatchParameters &ps) {
   PRECONDITION(a1, "bad atom");
   PRECONDITION(a2, "bad atom");
   // std::cerr << "\t\tatomCompat: "<< a1 << " " << a1->getIdx() << "-" << a2 <<
   // " " << a2->getIdx() << std::endl;
   bool res;
-  if (useQueryQueryMatches && a1->hasQuery() && a2->hasQuery()) {
+  if (ps.useQueryQueryMatches && a1->hasQuery() && a2->hasQuery()) {
     res = static_cast<const QueryAtom *>(a1)->QueryMatch(
         static_cast<const QueryAtom *>(a2));
   } else {
@@ -36,7 +35,7 @@ bool atomCompat(const Atom* a1, const Atom* a2,
   return res;
 }
 
-bool chiralAtomCompat(const Atom* &a1, const Atom* &a2) {
+bool chiralAtomCompat(const Atom *&a1, const Atom *&a2) {
   PRECONDITION(a1, "bad atom");
   PRECONDITION(a2, "bad atom");
   bool res = a1->Match(a2);
@@ -54,14 +53,21 @@ bool chiralAtomCompat(const Atom* &a1, const Atom* &a2) {
   return res;
 }
 
-bool bondCompat(const Bond* b1, const Bond* b2,
-                bool useQueryQueryMatches) {
+bool bondCompat(const Bond *b1, const Bond *b2,
+                const SubstructMatchParameters &ps) {
   PRECONDITION(b1, "bad bond");
   PRECONDITION(b2, "bad bond");
   bool res;
-  if (useQueryQueryMatches && b1->hasQuery() && b2->hasQuery()) {
+  if (ps.useQueryQueryMatches && b1->hasQuery() && b2->hasQuery()) {
     res = static_cast<const QueryBond *>(b1)->QueryMatch(
         static_cast<const QueryBond *>(b2));
+  } else if (ps.aromaticMatchesConjugated && !b1->hasQuery() &&
+             !b2->hasQuery() &&
+             ((b1->getBondType() == Bond::AROMATIC &&
+               b2->getBondType() == Bond::AROMATIC) ||
+              (b1->getBondType() == Bond::AROMATIC && b2->getIsConjugated()) ||
+              (b2->getBondType() == Bond::AROMATIC && b1->getIsConjugated()))) {
+    res = true;
   } else {
     res = b1->Match(b2);
   }
@@ -73,8 +79,9 @@ bool bondCompat(const Bond* b1, const Bond* b2,
       res = false;
     }
   }
-  // std::cout << "\t\tbondCompat: "<< b1->getIdx() << "-" << b2->getIdx() << ":
-  // " << res << std::endl;
+  // std::cerr << "\t\tbondCompat: " << b1->getIdx() << "-" << b2->getIdx() <<
+  // ":"
+  //           << res << std::endl;
   return res;
 }
 
@@ -90,7 +97,7 @@ void removeDuplicates(std::vector<MatchVectType> &v, unsigned int nAtoms) {
   //  that the 4 paths are equivalent in the semantics of the query.
   //  Also, OELib returns the same results
   //
-  std::vector<boost::dynamic_bitset<> > seen;
+  std::vector<boost::dynamic_bitset<>> seen;
   std::vector<MatchVectType> res;
   for (std::vector<MatchVectType>::const_iterator i = v.begin(); i != v.end();
        ++i) {
@@ -106,4 +113,4 @@ void removeDuplicates(std::vector<MatchVectType> &v, unsigned int nAtoms) {
   }
   v = res;
 }
-}
+}  // namespace RDKit
