@@ -1,6 +1,5 @@
-// $Id$
 //
-//  Copyright (C) 2011  Greg Landrum
+//  Copyright (C) 2011-2019  Greg Landrum
 //
 //   @@ All Rights Reserved @@
 //  This file is part of the RDKit.
@@ -74,7 +73,7 @@ class LocalForwardSDMolSupplier : public RDKit::ForwardSDMolSupplier {
 LocalForwardSDMolSupplier *FwdMolSupplIter(LocalForwardSDMolSupplier *self) {
   return self;
 }
-}
+}  // namespace
 
 namespace RDKit {
 
@@ -83,12 +82,12 @@ std::string fsdMolSupplierClassDoc =
 \n\
   Usage examples:\n\
 \n\
-    1) Lazy evaluation: the molecules are not constructed until we ask for them:\n\
+    1) Lazy evaluation: the molecules are not constructed until we ask for them:\n\n\
        >>> suppl = ForwardSDMolSupplier(file('in.sdf'))\n\
        >>> for mol in suppl:\n\
        ...    if mol is not None: mol.GetNumAtoms()\n\
 \n\
-    2) we can also read from compressed files: \n\
+    2) we can also read from compressed files: \n\n\
        >>> import gzip\n\
        >>> suppl = ForwardSDMolSupplier(gzip.open('in.sdf.gz'))\n\
        >>> for mol in suppl:\n \
@@ -123,9 +122,17 @@ struct forwardsdmolsup_wrap {
         .def("atEnd", &ForwardSDMolSupplier::atEnd,
              "Returns whether or not we have hit EOF.\n")
         .def("__iter__", &FwdMolSupplIter,
-             python::return_internal_reference<1>());
+             python::return_internal_reference<1>())
+        .def("GetProcessPropertyLists",
+             &ForwardSDMolSupplier::getProcessPropertyLists,
+             "returns whether or not any property lists that are present will "
+             "be processed when reading molecules")
+        .def("SetProcessPropertyLists",
+             &ForwardSDMolSupplier::setProcessPropertyLists,
+             "sets whether or not any property lists that are present will be "
+             "processed when reading molecules");
   };
 };
-}
+}  // namespace RDKit
 
 void wrap_forwardsdsupplier() { RDKit::forwardsdmolsup_wrap::wrap(); }
