@@ -37,26 +37,26 @@ std::string smilesMolSupplierClassDoc =
 \n \
   Usage examples:\n \
 \n \
-    1) Lazy evaluation: the molecules are not constructed until we ask for them:\n \
-       >>> suppl = SmilesMolSupplier('in.smi')\n \
-       >>> for mol in suppl:\n \
-       ...    mol.GetNumAtoms()\n \
+    1) Lazy evaluation: the molecules are not constructed until we ask for them:\n\n\
+       >>> suppl = SmilesMolSupplier('in.smi')\n\
+       >>> for mol in suppl:\n\
+       ...    mol.GetNumAtoms()\n\
 \n \
-    2) Lazy evaluation 2:\n \
-       >>> suppl = SmilesMolSupplier('in.smi')\n \
-       >>> mol1 = suppl.next()\n \
-       >>> mol2 = suppl.next()\n \
-       >>> suppl.reset()\n \
-       >>> mol3 = suppl.next()\n \
-       # mol3 and mol1 are the same: \
-       >>> MolToSmiles(mol3)==MolToSmiles(mol1)\n \
+    2) Lazy evaluation 2:\n\n\
+       >>> suppl = SmilesMolSupplier('in.smi')\n\
+       >>> mol1 = suppl.next()\n\
+       >>> mol2 = suppl.next()\n\
+       >>> suppl.reset()\n\
+       >>> mol3 = suppl.next()\n\n\
+       # mol3 and mol1 are the same:\
+       >>> MolToSmiles(mol3)==MolToSmiles(mol1)\n\
 \n \
     3) Random Access:  all molecules are constructed as soon as we ask for the\n \
-       length:\n \
-       >>> suppl = SmilesMolSupplier('in.smi')\n \
-       >>> nMols = len(suppl)\n \
-       >>> for i in range(nMols):\n \
-       ...   suppl[i].GetNumAtoms()\n \
+       length:\n\n\
+       >>> suppl = SmilesMolSupplier('in.smi')\n\
+       >>> nMols = len(suppl)\n\
+       >>> for i in range(nMols):\n\
+       ...   suppl[i].GetNumAtoms()\n\
 \n \
   If the input file has a title line and more than two columns (smiles and id), the\n\
   additional columns will be used to set properties on each molecule.  The properties\n\
@@ -124,6 +124,6 @@ struct smimolsup_wrap {
         python::return_value_policy<python::manage_new_object>());
   }
 };
-}
+}  // namespace RDKit
 
 void wrap_smisupplier() { RDKit::smimolsup_wrap::wrap(); }
