@@ -90,12 +90,12 @@ RDKIT_RDGENERAL_EXPORT std::ostream &toStream(std::ostream &);
   RDLog::toStream((__arg__->teestream) ? *(__arg__->teestream)  \
                                        : *(__arg__->dp_dest))
 
-RDKIT_RDGENERAL_EXPORT extern boost::logging::rdLogger *rdAppLog;
-RDKIT_RDGENERAL_EXPORT extern boost::logging::rdLogger *rdDebugLog;
-RDKIT_RDGENERAL_EXPORT extern boost::logging::rdLogger *rdInfoLog;
-RDKIT_RDGENERAL_EXPORT extern boost::logging::rdLogger *rdErrorLog;
-RDKIT_RDGENERAL_EXPORT extern boost::logging::rdLogger *rdWarningLog;
-RDKIT_RDGENERAL_EXPORT extern boost::logging::rdLogger *rdStatusLog;
+RDKIT_RDGENERAL_EXPORT extern std::shared_ptr<boost::logging::rdLogger> rdAppLog;
+RDKIT_RDGENERAL_EXPORT extern std::shared_ptr<boost::logging::rdLogger> rdDebugLog;
+RDKIT_RDGENERAL_EXPORT extern std::shared_ptr<boost::logging::rdLogger> rdInfoLog;
+RDKIT_RDGENERAL_EXPORT extern std::shared_ptr<boost::logging::rdLogger> rdErrorLog;
+RDKIT_RDGENERAL_EXPORT extern std::shared_ptr<boost::logging::rdLogger> rdWarningLog;
+RDKIT_RDGENERAL_EXPORT extern std::shared_ptr<boost::logging::rdLogger> rdStatusLog;
 
 #else
 #define BOOST_LOG_NO_LIB
