@@ -19,18 +19,20 @@
 #include <sstream>
 #include <iostream>
 #include <boost/cstdint.hpp>
-#include <boost/detail/endian.hpp>
+#include <boost/predef.h>
 
 namespace RDKit {
-// this code block for handling endian problems is from :
+// this code block for handling endian problems is adapted from :
 // http://stackoverflow.com/questions/105252/how-do-i-convert-between-big-endian-and-little-endian-values-in-c
 enum EEndian {
   LITTLE_ENDIAN_ORDER,
   BIG_ENDIAN_ORDER,
-#if defined(BOOST_LITTLE_ENDIAN)
+#if defined(BOOST_ENDIAN_LITTLE_BYTE) or defined(BOOST_ENDIAN_LITTLE_WORD)
   HOST_ENDIAN_ORDER = LITTLE_ENDIAN_ORDER
-#elif defined(BOOST_BIG_ENDIAN)
+#elif defined(BOOST_ENDIAN_BIG_BYTE)
   HOST_ENDIAN_ORDER = BIG_ENDIAN_ORDER
+#elif defined(BOOST_ENDIAN_BIG_WORD)
+#error "Cannot compile on word-swapped big-endian systems"
 #else
 #error "Failed to determine the system endian value"
 #endif
@@ -40,8 +42,7 @@ enum EEndian {
 // parameter (could sizeof be used?).
 template <class T, unsigned int size>
 inline T SwapBytes(T value) {
-  if (size < 2)
-    return value;
+  if (size < 2) return value;
 
   union {
     T value;
@@ -259,10 +260,9 @@ inline void streamRead(std::istream &ss, std::string &what, int version) {
   RDUNUSED_PARAM(version);
   unsigned int l;
   ss.read((char *)&l, sizeof(l));
-  char *buff = new char[l + 1];
+  char *buff = new char[l];
   ss.read(buff, sizeof(char) * l);
-  buff[l] = 0;
-  what = buff;
+  what = std::string(buff, l);
   delete[] buff;
 };
 
@@ -313,10 +313,24 @@ namespace DTags {
   const unsigned char VecBoolTag = 9;
   const unsigned char VecFloatTag = 10;
   const unsigned char VecDoubleTag = 11;
+
+  const unsigned char CustomTag = 0xFE;  // custom data
   const unsigned char EndTag = 0xFF;
 }
 
-inline bool isSerializable(const Dict::Pair &pair) {
+class CustomPropHandler {
+public:
+  virtual ~CustomPropHandler() {};
+  virtual const char *getPropName() const = 0;
+  virtual bool canSerialize(const RDValue &value) const = 0;
+  virtual bool read(std::istream &ss, RDValue &value) const = 0;
+  virtual bool write(std::ostream &ss, const RDValue &value) const = 0;
+  virtual CustomPropHandler* clone() const=0;
+};
+
+typedef std::vector<std::shared_ptr<const CustomPropHandler>> CustomPropHandlerVec;
+    
+inline bool isSerializable(const Dict::Pair &pair, const CustomPropHandlerVec &handlers = {}) {
   switch (pair.val.getTag()) {
     case RDTypeTag::StringTag:
     case RDTypeTag::IntTag:
@@ -330,16 +344,24 @@ inline bool isSerializable(const Dict::Pair &pair) {
     case RDTypeTag::VecUnsignedIntTag:
     case RDTypeTag::VecFloatTag:
     case RDTypeTag::VecDoubleTag:
-
       return true;
+    case RDTypeTag::AnyTag:
+      for(auto &handler: handlers) {
+        if(handler->canSerialize(pair.val)) {
+          return true;
+        }
+      }
     default:
       return false;
   }
 }
 
-inline bool streamWriteProp(std::ostream &ss, const Dict::Pair &pair) {
-  if (!isSerializable(pair)) return false;
-
+inline bool streamWriteProp(std::ostream &ss, const Dict::Pair &pair,
+                            const CustomPropHandlerVec &handlers = {}) {
+  if (!isSerializable(pair, handlers)) {
+    return false;
+  }
+  
   streamWrite(ss, pair.key);
   switch (pair.val.getTag()) {
     case RDTypeTag::StringTag:
@@ -388,14 +410,27 @@ inline bool streamWriteProp(std::ostream &ss, const Dict::Pair &pair) {
       streamWriteVec(ss, rdvalue_cast<std::vector<unsigned int>>(pair.val));
       break;
     default:
-      std::cerr << "Failed to write " << pair.key << std::endl;
+      for(auto &handler: handlers) {
+        if(handler->canSerialize(pair.val)) {
+          // The form of a custom tag is
+          //  CustomTag
+          //  customPropName (must be unique)
+          //  custom serialization
+          streamWrite(ss, DTags::CustomTag);
+          streamWrite(ss, std::string(handler->getPropName()));
+          handler->write(ss, pair.val);
+          return true;
+        }
+      }
+      
       return false;
   }
   return true;
 }
 
 inline bool streamWriteProps(std::ostream &ss, const RDProps &props,
-                             bool savePrivate=false, bool saveComputed=false) {
+                             bool savePrivate=false, bool saveComputed=false,
+                             const CustomPropHandlerVec &handlers = {}) {
   STR_VECT propsToSave = props.getPropList(savePrivate, saveComputed);
   std::set<std::string> propnames(propsToSave.begin(), propsToSave.end());
   
@@ -404,8 +439,10 @@ inline bool streamWriteProps(std::ostream &ss, const RDProps &props,
   for(Dict::DataType::const_iterator it = dict.getData().begin();
       it != dict.getData().end();
       ++it) {
-    if(isSerializable(*it) && propnames.find(it->key) != propnames.end()) {
-      count ++;
+    if(propnames.find(it->key) != propnames.end()) {
+      if (isSerializable(*it, handlers)) {
+        count ++;
+      }
     }
   }
 
@@ -416,10 +453,10 @@ inline bool streamWriteProps(std::ostream &ss, const RDProps &props,
       it != dict.getData().end();
       ++it) {
     if (propnames.find(it->key) != propnames.end()) {
-      if (isSerializable(*it)) {
+      if (isSerializable(*it, handlers)) {
         // note - not all properties are serializable, this may be
         //  a null op
-        if (streamWriteProp(ss, *it)) {
+        if (streamWriteProp(ss, *it, handlers)) {
           writtenCount++;
         }
       }
@@ -457,35 +494,59 @@ inline void readRDStringVecValue(std::istream &ss, RDValue &value) {
   value = v;
 }
 
-inline bool streamReadProp(std::istream &ss, Dict::Pair &pair) {
+inline bool streamReadProp(std::istream &ss, Dict::Pair &pair,
+                           bool& dictHasNonPOD,
+                           const CustomPropHandlerVec &handlers = {}) {
   int version=0;
   streamRead(ss, pair.key, version);
 
   unsigned char type;
   streamRead(ss, type);
   switch(type) {
-    case DTags::StringTag: readRDValueString(ss, pair.val); break;
     case DTags::IntTag: readRDValue<int>(ss, pair.val); break;
     case DTags::UnsignedIntTag: readRDValue<unsigned int>(ss, pair.val); break;
     case DTags::BoolTag: readRDValue<bool>(ss, pair.val); break;
     case DTags::FloatTag: readRDValue<float>(ss, pair.val); break;
     case DTags::DoubleTag: readRDValue<double>(ss, pair.val); break;
 
+    case DTags::StringTag:
+      readRDValueString(ss, pair.val);
+      dictHasNonPOD = true;
+      break;
     case DTags::VecStringTag:
       readRDStringVecValue(ss, pair.val);
+      dictHasNonPOD = true;
       break;
     case DTags::VecIntTag:
       readRDVecValue<int>(ss, pair.val);
+      dictHasNonPOD = true;
       break;
     case DTags::VecUIntTag:
       readRDVecValue<unsigned int>(ss, pair.val);
+      dictHasNonPOD = true;
       break;
     case DTags::VecFloatTag:
       readRDVecValue<float>(ss, pair.val);
+      dictHasNonPOD = true;
       break;
     case DTags::VecDoubleTag:
       readRDVecValue<double>(ss, pair.val);
+      dictHasNonPOD = true;
       break;
+    case DTags::CustomTag:
+      {
+        std::string propType;
+        int version=0;
+        streamRead(ss, propType, version);
+        for(auto &handler: handlers) {
+          if(propType == handler->getPropName()) {
+            handler->read(ss, pair.val);
+            dictHasNonPOD = true;
+            return true;
+          }
+        }
+        return false;
+      }
 
     default:
       return false;
@@ -493,14 +554,17 @@ inline bool streamReadProp(std::istream &ss, Dict::Pair &pair) {
   return true;
 }
 
-inline unsigned int streamReadProps(std::istream &ss, RDProps &props) {
+inline unsigned int streamReadProps(std::istream &ss, RDProps &props,
+                                    const CustomPropHandlerVec &handlers = {}) {
   unsigned int count;
   streamRead(ss, count);
 
   Dict &dict = props.getDict();
+  dict.reset(); // Clear data before repopulating
   dict.getData().resize(count);
   for(unsigned index = 0; index<count; ++index) {
-    CHECK_INVARIANT(streamReadProp(ss, dict.getData()[index]),
+    CHECK_INVARIANT(streamReadProp(ss, dict.getData()[index], dict.getNonPODStatus(),
+                                   handlers),
                     "Corrupted property serialization detected");
   }
 
