@@ -85,7 +85,7 @@ namespace AvalonTools {
 
       MyFree(fingerprint);
     };
-  
+
     void reaccsToCounts(struct reaccs_molecule_t *molPtr,SparseIntVect<boost::uint32_t> &res,
                         unsigned int bitFlags=32767U,bool isQuery=false,
                         unsigned int nBytes=64){
@@ -99,7 +99,7 @@ namespace AvalonTools {
       }
       MyFree((char *)fingerprint);
     };
-  
+
     void reaccsToFingerprint(struct reaccs_molecule_t *molPtr,ExplicitBitVect &res,
                              unsigned int bitFlags=32767U,bool isQuery=false,
                              bool resetVect=true,unsigned int nBytes=64){
@@ -123,7 +123,7 @@ namespace AvalonTools {
       }
       MyFree(fingerprint);
     };
-  
+
     struct reaccs_molecule_t *reaccsGetCoords(struct reaccs_molecule_t *molPtr){
       PRECONDITION(molPtr,"bad molecule");
 
@@ -170,7 +170,7 @@ namespace AvalonTools {
     } else {
       std::string rdMB=MolToMolBlock(mol);
       res = getCanonSmiles(rdMB,false,flags);
-      
+
     }
     return res;
   }
@@ -215,14 +215,23 @@ namespace AvalonTools {
   }
 
   unsigned int set2DCoords(ROMol &mol,bool clearConfs){
-    struct reaccs_molecule_t *mp=molToReaccs(mol);
+    auto smiles = MolToSmiles(mol);
+    struct reaccs_molecule_t *mp=stringToReaccs(smiles,true);
     struct reaccs_molecule_t *mp2=reaccsGetCoords(mp);
     TEST_ASSERT(mp2->n_atoms==mol.getNumAtoms());
 
     auto *conf = new RDKit::Conformer(mol.getNumAtoms());
     conf->set3D(false);
+
+    // Atoms in the intermediate smiles representation may be ordered
+    // differently compared to the original input molecule.
+    // Make sure that output coordinates are assigned in the correct order.
+    std::vector<unsigned int> atomOrdering;
+    mol.getProp(common_properties::_smilesAtomOutputOrder, atomOrdering);
     for(unsigned int i=0;i<mol.getNumAtoms();++i){
-      RDGeom::Point3D loc(mp2->atom_array[i].x,mp2->atom_array[i].y,mp2->atom_array[i].z);
+      auto x = mp2->atom_array[atomOrdering[i]].x;
+      auto y = mp2->atom_array[atomOrdering[i]].y;
+      RDGeom::Point3D loc(x,y,0.);
       conf->setAtomPos(i,loc);
     }
 
@@ -252,7 +261,7 @@ namespace AvalonTools {
       FreeMolecule(mp);
       FreeMolecule(mp2);
       MyFree(molB);
-    } 
+    }
     return res;
   }
 
@@ -338,7 +347,7 @@ namespace AvalonTools {
     }
     return res;
   }
-  
+
   /**
    * Wrapper around struchk.CheckMol
    * The molecule to check is passed in as a string. isSmiles
@@ -349,7 +358,7 @@ namespace AvalonTools {
    **/
   int checkMolString(const std::string &data, const bool isSmiles,
 		     struct reaccs_molecule_t **mp) {
-	// clean msg list from previous call (if no previous call, freemsglist does nothing)	
+	// clean msg list from previous call (if no previous call, freemsglist does nothing)
     FreeMsgList();
 
     int errs = 0;
@@ -388,7 +397,7 @@ namespace AvalonTools {
   }
 
   RDKit::ROMOL_SPTR checkMol(int &errs, RDKit::ROMol& inMol) {
-	// clean msg list from previous call (if no previous call, freemsglist does nothing)	
+	// clean msg list from previous call (if no previous call, freemsglist does nothing)
     FreeMsgList();
 
     struct reaccs_molecule_t *mp;
