@@ -10,7 +10,6 @@ from rdkit.Chem.Draw.MolDrawing import MolDrawing, DrawingOptions
 from rdkit.Chem.Draw.rdMolDraw2D import *
 from rdkit.Chem import rdDepictor
 from rdkit import Chem
-from rdkit.six import iteritems
 
 
 def _getCanvas():
@@ -255,7 +254,7 @@ def MolToMPL(mol, size=(300, 300), kekulize=True, wedgeBonds=True, imageType=Non
 
   drawer.AddMol(mol, **kwargs)
   omol._atomPs = drawer.atomPs[mol]
-  for k, v in iteritems(omol._atomPs):
+  for k, v in omol._atomPs.items():
     omol._atomPs[k] = canvas.rescalePt(v)
   canvas._figure.set_size_inches(float(size[0]) / 100, float(size[1]) / 100)
   return canvas._figure
