@@ -32,146 +32,146 @@ PY2 = sys.version_info[0] == 2
 PY3 = sys.version_info[0] == 3
 
 if PY3:
-  string_types = str,
-  integer_types = int,
-  class_types = type,
-  text_type = str
-  binary_type = bytes
+    string_types = str,
+    integer_types = int,
+    class_types = type,
+    text_type = str
+    binary_type = bytes
 
-  MAXSIZE = sys.maxsize
+    MAXSIZE = sys.maxsize
 else:
-  string_types = basestring,
-  integer_types = (int, long)
-  class_types = (type, types.ClassType)
-  text_type = unicode
-  binary_type = str
+    string_types = basestring,
+    integer_types = (int, long)
+    class_types = (type, types.ClassType)
+    text_type = unicode
+    binary_type = str
 
-  if sys.platform.startswith("java"):
-    # Jython always uses 32 bits.
-    MAXSIZE = int((1 << 31) - 1)
-  else:
-    # It's possible to have sizeof(long) != sizeof(Py_ssize_t).
-    class X(object):
-
-      def __len__(self):
-        return 1 << 31
-
-    try:
-      len(X())
-    except OverflowError:
-      # 32-bit
-      MAXSIZE = int((1 << 31) - 1)
+    if sys.platform.startswith("java"):
+        # Jython always uses 32 bits.
+        MAXSIZE = int((1 << 31) - 1)
     else:
-      # 64-bit
-      MAXSIZE = int((1 << 63) - 1)
-    del X
+        # It's possible to have sizeof(long) != sizeof(Py_ssize_t).
+        class X(object):
+
+            def __len__(self):
+                return 1 << 31
+
+        try:
+            len(X())
+        except OverflowError:
+            # 32-bit
+            MAXSIZE = int((1 << 31) - 1)
+        else:
+            # 64-bit
+            MAXSIZE = int((1 << 63) - 1)
+        del X
 
 
 def _add_doc(func, doc):
-  """Add documentation to a function."""
-  func.__doc__ = doc
+    """Add documentation to a function."""
+    func.__doc__ = doc
 
 
 def _import_module(name):
-  """Import module, returning the module after the last dot."""
-  __import__(name)
-  return sys.modules[name]
+    """Import module, returning the module after the last dot."""
+    __import__(name)
+    return sys.modules[name]
 
 
 class _LazyDescr(object):
 
-  def __init__(self, name):
-    self.name = name
+    def __init__(self, name):
+        self.name = name
 
-  def __get__(self, obj, tp):
-    try:
-      result = self._resolve()
-    except ImportError:
-      # See the nice big comment in MovedModule.__getattr__.
-      raise AttributeError("%s could not be imported " % self.name)
-    setattr(obj, self.name, result)  # Invokes __set__.
-    # This is a bit ugly, but it avoids running this again.
-    delattr(obj.__class__, self.name)
-    return result
+    def __get__(self, obj, tp):
+        try:
+            result = self._resolve()
+        except ImportError:
+            # See the nice big comment in MovedModule.__getattr__.
+            raise AttributeError("%s could not be imported " % self.name)
+        setattr(obj, self.name, result)  # Invokes __set__.
+        # This is a bit ugly, but it avoids running this again.
+        delattr(obj.__class__, self.name)
+        return result
 
 
 class MovedModule(_LazyDescr):
 
-  def __init__(self, name, old, new=None):
-    super(MovedModule, self).__init__(name)
-    if PY3:
-      if new is None:
-        new = name
-      self.mod = new
-    else:
-      self.mod = old
+    def __init__(self, name, old, new=None):
+        super(MovedModule, self).__init__(name)
+        if PY3:
+            if new is None:
+                new = name
+            self.mod = new
+        else:
+            self.mod = old
 
-  def _resolve(self):
-    return _import_module(self.mod)
+    def _resolve(self):
+        return _import_module(self.mod)
 
-  def __getattr__(self, attr):
-    # It turns out many Python frameworks like to traverse sys.modules and
-    # try to load various attributes. This causes problems if this is a
-    # platform-specific module on the wrong platform, like _winreg on
-    # Unixes. Therefore, we silently pretend unimportable modules do not
-    # have any attributes. See issues #51, #53, #56, and #63 for the full
-    # tales of woe.
-    #
-    # First, if possible, avoid loading the module just to look at __file__,
-    # __name__, or __path__.
-    if (attr in ("__file__", "__name__", "__path__") and self.mod not in sys.modules):
-      raise AttributeError(attr)
-    try:
-      _module = self._resolve()
-    except ImportError:
-      raise AttributeError(attr)
-    value = getattr(_module, attr)
-    setattr(self, attr, value)
-    return value
+    def __getattr__(self, attr):
+        # It turns out many Python frameworks like to traverse sys.modules and
+        # try to load various attributes. This causes problems if this is a
+        # platform-specific module on the wrong platform, like _winreg on
+        # Unixes. Therefore, we silently pretend unimportable modules do not
+        # have any attributes. See issues #51, #53, #56, and #63 for the full
+        # tales of woe.
+        #
+        # First, if possible, avoid loading the module just to look at __file__,
+        # __name__, or __path__.
+        if (attr in ("__file__", "__name__", "__path__") and self.mod not in sys.modules):
+            raise AttributeError(attr)
+        try:
+            _module = self._resolve()
+        except ImportError:
+            raise AttributeError(attr)
+        value = getattr(_module, attr)
+        setattr(self, attr, value)
+        return value
 
 
 class _LazyModule(types.ModuleType):
 
-  def __init__(self, name):
-    super(_LazyModule, self).__init__(name)
-    self.__doc__ = self.__class__.__doc__
+    def __init__(self, name):
+        super(_LazyModule, self).__init__(name)
+        self.__doc__ = self.__class__.__doc__
 
-  def __dir__(self):
-    attrs = ["__doc__", "__name__"]
-    attrs += [attr.name for attr in self._moved_attributes]
-    return attrs
+    def __dir__(self):
+        attrs = ["__doc__", "__name__"]
+        attrs += [attr.name for attr in self._moved_attributes]
+        return attrs
 
-  # Subclasses should override this
-  _moved_attributes = []
+    # Subclasses should override this
+    _moved_attributes = []
 
 
 class MovedAttribute(_LazyDescr):
 
-  def __init__(self, name, old_mod, new_mod, old_attr=None, new_attr=None):
-    super(MovedAttribute, self).__init__(name)
-    if PY3:
-      if new_mod is None:
-        new_mod = name
-      self.mod = new_mod
-      if new_attr is None:
-        if old_attr is None:
-          new_attr = name
+    def __init__(self, name, old_mod, new_mod, old_attr=None, new_attr=None):
+        super(MovedAttribute, self).__init__(name)
+        if PY3:
+            if new_mod is None:
+                new_mod = name
+            self.mod = new_mod
+            if new_attr is None:
+                if old_attr is None:
+                    new_attr = name
+                else:
+                    new_attr = old_attr
+            self.attr = new_attr
         else:
-          new_attr = old_attr
-      self.attr = new_attr
-    else:
-      self.mod = old_mod
-      if old_attr is None:
-        old_attr = name
-      self.attr = old_attr
+            self.mod = old_mod
+            if old_attr is None:
+                old_attr = name
+            self.attr = old_attr
 
-  def _resolve(self):
-    module = _import_module(self.mod)
-    return getattr(module, self.attr)
+    def _resolve(self):
+        module = _import_module(self.mod)
+        return getattr(module, self.attr)
 
 
 class _MovedItems(_LazyModule):
-  """Lazy loading of moved objects"""
+    """Lazy loading of moved objects"""
 
 
 _moved_attributes = [
@@ -205,8 +205,8 @@ _moved_attributes = [
   MovedModule("BaseHTTPServer", "BaseHTTPServer", "http.server"),
   MovedModule("CGIHTTPServer", "CGIHTTPServer", "http.server"),
   MovedModule("SimpleHTTPServer", "SimpleHTTPServer", "http.server"),
-  #MovedModule("cPickle", "cPickle", "pickle"),
-  MovedModule("cPickle", "rdkit._py2_pickle", "pickle"),
+  #MovedModule("pickle", "pickle", "pickle"),
+  MovedModule("pickle", "rdkit._py2_pickle", "pickle"),
   MovedModule("queue", "Queue"),
   MovedModule("reprlib", "repr"),
   MovedModule("socketserver", "SocketServer"),
@@ -235,9 +235,9 @@ _moved_attributes = [
   MovedModule("winreg", "_winreg"),
 ]
 for attr in _moved_attributes:
-  setattr(_MovedItems, attr.name, attr)
-  if isinstance(attr, MovedModule):
-    sys.modules[__name__ + ".moves." + attr.name] = attr
+    setattr(_MovedItems, attr.name, attr)
+    if isinstance(attr, MovedModule):
+        sys.modules[__name__ + ".moves." + attr.name] = attr
 del attr
 
 _MovedItems._moved_attributes = _moved_attributes
@@ -246,7 +246,7 @@ moves = sys.modules[__name__ + ".moves"] = _MovedItems(__name__ + ".moves")
 
 
 class Module_six_moves_urllib_parse(_LazyModule):
-  """Lazy loading of moved objects in six.moves.urllib_parse"""
+    """Lazy loading of moved objects in six.moves.urllib_parse"""
 
 
 _urllib_parse_moved_attributes = [
@@ -268,18 +268,18 @@ _urllib_parse_moved_attributes = [
   MovedAttribute("splitquery", "urllib", "urllib.parse"),
 ]
 for attr in _urllib_parse_moved_attributes:
-  setattr(Module_six_moves_urllib_parse, attr.name, attr)
+    setattr(Module_six_moves_urllib_parse, attr.name, attr)
 del attr
 
 Module_six_moves_urllib_parse._moved_attributes = _urllib_parse_moved_attributes
 
 sys.modules[__name__ + ".moves.urllib_parse"] = sys.modules[
-  __name__ + ".moves.urllib.parse"] = Module_six_moves_urllib_parse(__name__ +
-                                                                    ".moves.urllib_parse")
+  __name__ + ".moves.urllib.parse"] = Module_six_moves_urllib_parse(__name__
+                                                                    + ".moves.urllib_parse")
 
 
 class Module_six_moves_urllib_error(_LazyModule):
-  """Lazy loading of moved objects in six.moves.urllib_error"""
+    """Lazy loading of moved objects in six.moves.urllib_error"""
 
 
 _urllib_error_moved_attributes = [
@@ -288,18 +288,18 @@ _urllib_error_moved_attributes = [
   MovedAttribute("ContentTooShortError", "urllib", "urllib.error"),
 ]
 for attr in _urllib_error_moved_attributes:
-  setattr(Module_six_moves_urllib_error, attr.name, attr)
+    setattr(Module_six_moves_urllib_error, attr.name, attr)
 del attr
 
 Module_six_moves_urllib_error._moved_attributes = _urllib_error_moved_attributes
 
 sys.modules[__name__ + ".moves.urllib_error"] = sys.modules[
-  __name__ + ".moves.urllib.error"] = Module_six_moves_urllib_error(__name__ +
-                                                                    ".moves.urllib.error")
+  __name__ + ".moves.urllib.error"] = Module_six_moves_urllib_error(__name__
+                                                                    + ".moves.urllib.error")
 
 
 class Module_six_moves_urllib_request(_LazyModule):
-  """Lazy loading of moved objects in six.moves.urllib_request"""
+    """Lazy loading of moved objects in six.moves.urllib_request"""
 
 
 _urllib_request_moved_attributes = [
@@ -338,18 +338,18 @@ _urllib_request_moved_attributes = [
   MovedAttribute("proxy_bypass", "urllib", "urllib.request"),
 ]
 for attr in _urllib_request_moved_attributes:
-  setattr(Module_six_moves_urllib_request, attr.name, attr)
+    setattr(Module_six_moves_urllib_request, attr.name, attr)
 del attr
 
 Module_six_moves_urllib_request._moved_attributes = _urllib_request_moved_attributes
 
 sys.modules[__name__ + ".moves.urllib_request"] = sys.modules[
-  __name__ + ".moves.urllib.request"] = Module_six_moves_urllib_request(__name__ +
-                                                                        ".moves.urllib.request")
+  __name__ + ".moves.urllib.request"] = Module_six_moves_urllib_request(__name__
+                                                                        + ".moves.urllib.request")
 
 
 class Module_six_moves_urllib_response(_LazyModule):
-  """Lazy loading of moved objects in six.moves.urllib_response"""
+    """Lazy loading of moved objects in six.moves.urllib_response"""
 
 
 _urllib_response_moved_attributes = [
@@ -359,25 +359,25 @@ _urllib_response_moved_attributes = [
   MovedAttribute("addinfourl", "urllib", "urllib.response"),
 ]
 for attr in _urllib_response_moved_attributes:
-  setattr(Module_six_moves_urllib_response, attr.name, attr)
+    setattr(Module_six_moves_urllib_response, attr.name, attr)
 del attr
 
 Module_six_moves_urllib_response._moved_attributes = _urllib_response_moved_attributes
 
 sys.modules[__name__ + ".moves.urllib_response"] = sys.modules[
-  __name__ + ".moves.urllib.response"] = Module_six_moves_urllib_response(__name__ +
-                                                                          ".moves.urllib.response")
+  __name__ + ".moves.urllib.response"] = Module_six_moves_urllib_response(__name__
+                                                                          + ".moves.urllib.response")
 
 
 class Module_six_moves_urllib_robotparser(_LazyModule):
-  """Lazy loading of moved objects in six.moves.urllib_robotparser"""
+    """Lazy loading of moved objects in six.moves.urllib_robotparser"""
 
 
 _urllib_robotparser_moved_attributes = [
   MovedAttribute("RobotFileParser", "robotparser", "urllib.robotparser"),
 ]
 for attr in _urllib_robotparser_moved_attributes:
-  setattr(Module_six_moves_urllib_robotparser, attr.name, attr)
+    setattr(Module_six_moves_urllib_robotparser, attr.name, attr)
 del attr
 
 Module_six_moves_urllib_robotparser._moved_attributes = _urllib_robotparser_moved_attributes
@@ -388,93 +388,93 @@ sys.modules[__name__ + ".moves.urllib_robotparser"] = sys.modules[
 
 
 class Module_six_moves_urllib(types.ModuleType):
-  """Create a six.moves.urllib namespace that resembles the Python 3 namespace"""
-  parse = sys.modules[__name__ + ".moves.urllib_parse"]
-  error = sys.modules[__name__ + ".moves.urllib_error"]
-  request = sys.modules[__name__ + ".moves.urllib_request"]
-  response = sys.modules[__name__ + ".moves.urllib_response"]
-  robotparser = sys.modules[__name__ + ".moves.urllib_robotparser"]
+    """Create a six.moves.urllib namespace that resembles the Python 3 namespace"""
+    parse = sys.modules[__name__ + ".moves.urllib_parse"]
+    error = sys.modules[__name__ + ".moves.urllib_error"]
+    request = sys.modules[__name__ + ".moves.urllib_request"]
+    response = sys.modules[__name__ + ".moves.urllib_response"]
+    robotparser = sys.modules[__name__ + ".moves.urllib_robotparser"]
 
-  def __dir__(self):
-    return ['parse', 'error', 'request', 'response', 'robotparser']
+    def __dir__(self):
+        return ['parse', 'error', 'request', 'response', 'robotparser']
 
 
 sys.modules[__name__ + ".moves.urllib"] = Module_six_moves_urllib(__name__ + ".moves.urllib")
 
 
 def add_move(move):
-  """Add an item to six.moves."""
-  setattr(_MovedItems, move.name, move)
+    """Add an item to six.moves."""
+    setattr(_MovedItems, move.name, move)
 
 
 def remove_move(name):
-  """Remove item from six.moves."""
-  try:
-    delattr(_MovedItems, name)
-  except AttributeError:
+    """Remove item from six.moves."""
     try:
-      del moves.__dict__[name]
-    except KeyError:
-      raise AttributeError("no such move, %r" % (name, ))
+        delattr(_MovedItems, name)
+    except AttributeError:
+        try:
+            del moves.__dict__[name]
+        except KeyError:
+            raise AttributeError("no such move, %r" % (name, ))
 
 
 if PY3:
-  _meth_func = "__func__"
-  _meth_self = "__self__"
+    _meth_func = "__func__"
+    _meth_self = "__self__"
 
-  _func_closure = "__closure__"
-  _func_code = "__code__"
-  _func_defaults = "__defaults__"
-  _func_globals = "__globals__"
+    _func_closure = "__closure__"
+    _func_code = "__code__"
+    _func_defaults = "__defaults__"
+    _func_globals = "__globals__"
 else:
-  _meth_func = "im_func"
-  _meth_self = "im_self"
+    _meth_func = "im_func"
+    _meth_self = "im_self"
 
-  _func_closure = "func_closure"
-  _func_code = "func_code"
-  _func_defaults = "func_defaults"
-  _func_globals = "func_globals"
+    _func_closure = "func_closure"
+    _func_code = "func_code"
+    _func_defaults = "func_defaults"
+    _func_globals = "func_globals"
 
 try:
-  advance_iterator = next
+    advance_iterator = next
 except NameError:
 
-  def advance_iterator(it):
-    return it.next()
+    def advance_iterator(it):
+        return it.next()
 
 
 next = advance_iterator
 
 try:
-  callable = callable
+    callable = callable
 except NameError:
 
-  def callable(obj):
-    return any("__call__" in klass.__dict__ for klass in type(obj).__mro__)
+    def callable(obj):
+        return any("__call__" in klass.__dict__ for klass in type(obj).__mro__)
 
 
 if PY3:
 
-  def get_unbound_function(unbound):
-    return unbound
+    def get_unbound_function(unbound):
+        return unbound
 
-  create_bound_method = types.MethodType
+    create_bound_method = types.MethodType
 
-  Iterator = object
+    Iterator = object
 else:
 
-  def get_unbound_function(unbound):
-    return unbound.im_func
+    def get_unbound_function(unbound):
+        return unbound.im_func
 
-  def create_bound_method(func, obj):
-    return types.MethodType(func, obj, obj.__class__)
+    def create_bound_method(func, obj):
+        return types.MethodType(func, obj, obj.__class__)
 
-  class Iterator(object):
+    class Iterator(object):
 
-    def next(self):
-      return type(self).__next__(self)
+        def next(self):
+            return type(self).__next__(self)
 
-  callable = callable
+    callable = callable
 _add_doc(get_unbound_function, """Get the function out of a possibly unbound function""")
 
 get_method_function = operator.attrgetter(_meth_func)
@@ -486,30 +486,30 @@ get_function_globals = operator.attrgetter(_func_globals)
 
 if PY3:
 
-  def iterkeys(d, **kw):
-    return iter(d.keys(**kw))
+    def iterkeys(d, **kw):
+        return iter(d.keys(**kw))
 
-  def itervalues(d, **kw):
-    return iter(d.values(**kw))
+    def itervalues(d, **kw):
+        return iter(d.values(**kw))
 
-  def iteritems(d, **kw):
-    return iter(d.items(**kw))
+    def iteritems(d, **kw):
+        return iter(d.items(**kw))
 
-  def iterlists(d, **kw):
-    return iter(d.lists(**kw))
+    def iterlists(d, **kw):
+        return iter(d.lists(**kw))
 else:
 
-  def iterkeys(d, **kw):
-    return iter(d.iterkeys(**kw))
+    def iterkeys(d, **kw):
+        return iter(d.iterkeys(**kw))
 
-  def itervalues(d, **kw):
-    return iter(d.itervalues(**kw))
+    def itervalues(d, **kw):
+        return iter(d.itervalues(**kw))
 
-  def iteritems(d, **kw):
-    return iter(d.iteritems(**kw))
+    def iteritems(d, **kw):
+        return iter(d.iteritems(**kw))
 
-  def iterlists(d, **kw):
-    return iter(d.iterlists(**kw))
+    def iterlists(d, **kw):
+        return iter(d.iterlists(**kw))
 
 
 _add_doc(iterkeys, "Return an iterator over the keys of a dictionary.")
@@ -519,163 +519,165 @@ _add_doc(iterlists, "Return an iterator over the (key, [values]) pairs of a dict
 
 if PY3:
 
-  def b(s):
-    return s.encode("latin-1")
+    def b(s):
+        return s.encode("latin-1")
 
-  def u(s):
-    return s
+    def u(s):
+        return s
 
-  unichr = chr
-  if sys.version_info[1] <= 1:
+    unichr = chr
+    if sys.version_info[1] <= 1:
 
-    def int2byte(i):
-      return bytes((i, ))
-  else:
-    # This is about 2x faster than the implementation above on 3.2+
-    int2byte = operator.methodcaller("to_bytes", 1, "big")
-  byte2int = operator.itemgetter(0)
-  indexbytes = operator.getitem
-  iterbytes = iter
-  import io
-  StringIO = io.StringIO
-  BytesIO = io.BytesIO
+        def int2byte(i):
+            return bytes((i, ))
+    else:
+        # This is about 2x faster than the implementation above on 3.2+
+        int2byte = operator.methodcaller("to_bytes", 1, "big")
+    byte2int = operator.itemgetter(0)
+    indexbytes = operator.getitem
+    iterbytes = iter
+    import io
+    StringIO = io.StringIO
+    BytesIO = io.BytesIO
 else:
 
-  def b(s):
-    return s
-  # Workaround for standalone backslash
-  def u(s):
-    return unicode(s.replace(r'\\', r'\\\\'), "unicode_escape")
+    def b(s):
+        return s
+    # Workaround for standalone backslash
 
-  unichr = unichr
-  int2byte = chr
+    def u(s):
+        return unicode(s.replace(r'\\', r'\\\\'), "unicode_escape")
 
-  def byte2int(bs):
-    return ord(bs[0])
+    unichr = unichr
+    int2byte = chr
 
-  def indexbytes(buf, i):
-    return ord(buf[i])
+    def byte2int(bs):
+        return ord(bs[0])
 
-  def iterbytes(buf):
-    return (ord(byte) for byte in buf)
+    def indexbytes(buf, i):
+        return ord(buf[i])
 
-  import StringIO
-  StringIO = BytesIO = StringIO.StringIO
+    def iterbytes(buf):
+        return (ord(byte) for byte in buf)
+
+    import StringIO
+    StringIO = BytesIO = StringIO.StringIO
 _add_doc(b, """Byte literal""")
 _add_doc(u, """Text literal""")
 
 if PY3:
-  exec_ = getattr(moves.builtins, "exec")
+    exec_ = getattr(moves.builtins, "exec")
 
-  def reraise(tp, value, tb=None):
-    if value.__traceback__ is not tb:
-      raise value.with_traceback(tb)
-    raise value
+    def reraise(tp, value, tb=None):
+        if value.__traceback__ is not tb:
+            raise value.with_traceback(tb)
+        raise value
 
 else:
 
-  def exec_(_code_, _globs_=None, _locs_=None):
-    """Execute code in a namespace."""
-    if _globs_ is None:
-      frame = sys._getframe(1)
-      _globs_ = frame.f_globals
-      if _locs_ is None:
-        _locs_ = frame.f_locals
-      del frame
-    elif _locs_ is None:
-      _locs_ = _globs_
-    exec("""exec _code_ in _globs_, _locs_""")
+    def exec_(_code_, _globs_=None, _locs_=None):
+        """Execute code in a namespace."""
+        if _globs_ is None:
+            frame = sys._getframe(1)
+            _globs_ = frame.f_globals
+            if _locs_ is None:
+                _locs_ = frame.f_locals
+            del frame
+        elif _locs_ is None:
+            _locs_ = _globs_
+        exec("""exec _code_ in _globs_, _locs_""")
 
-  exec_("""def reraise(tp, value, tb=None):
+    exec_("""def reraise(tp, value, tb=None):
     raise tp, value, tb
 """)
 
 print_ = getattr(moves.builtins, "print", None)
 if print_ is None:
 
-  def print_(*args, **kwargs):
-    """The new-style print function for Python 2.4 and 2.5."""
-    fp = kwargs.pop("file", sys.stdout)
-    if fp is None:
-      return
+    def print_(*args, **kwargs):
+        """The new-style print function for Python 2.4 and 2.5."""
+        fp = kwargs.pop("file", sys.stdout)
+        if fp is None:
+            return
 
-    def write(data):
-      if not isinstance(data, basestring):
-        data = str(data)
-      # If the file has an encoding, encode unicode with it.
-      if (isinstance(fp, file) and isinstance(data, unicode) and fp.encoding is not None):
-        errors = getattr(fp, "errors", None)
-        if errors is None:
-          errors = "strict"
-        data = data.encode(fp.encoding, errors)
-      fp.write(data)
+        def write(data):
+            if not isinstance(data, basestring):
+                data = str(data)
+            # If the file has an encoding, encode unicode with it.
+            if (isinstance(fp, file) and isinstance(data, unicode) and fp.encoding is not None):
+                errors = getattr(fp, "errors", None)
+                if errors is None:
+                    errors = "strict"
+                data = data.encode(fp.encoding, errors)
+            fp.write(data)
 
-    want_unicode = False
-    sep = kwargs.pop("sep", None)
-    if sep is not None:
-      if isinstance(sep, unicode):
-        want_unicode = True
-      elif not isinstance(sep, str):
-        raise TypeError("sep must be None or a string")
-    end = kwargs.pop("end", None)
-    if end is not None:
-      if isinstance(end, unicode):
-        want_unicode = True
-      elif not isinstance(end, str):
-        raise TypeError("end must be None or a string")
-    if kwargs:
-      raise TypeError("invalid keyword arguments to print()")
-    if not want_unicode:
-      for arg in args:
-        if isinstance(arg, unicode):
-          want_unicode = True
-          break
-    if want_unicode:
-      newline = unicode("\n")
-      space = unicode(" ")
-    else:
-      newline = "\n"
-      space = " "
-    if sep is None:
-      sep = space
-    if end is None:
-      end = newline
-    for i, arg in enumerate(args):
-      if i:
-        write(sep)
-      write(arg)
-    write(end)
+        want_unicode = False
+        sep = kwargs.pop("sep", None)
+        if sep is not None:
+            if isinstance(sep, unicode):
+                want_unicode = True
+            elif not isinstance(sep, str):
+                raise TypeError("sep must be None or a string")
+        end = kwargs.pop("end", None)
+        if end is not None:
+            if isinstance(end, unicode):
+                want_unicode = True
+            elif not isinstance(end, str):
+                raise TypeError("end must be None or a string")
+        if kwargs:
+            raise TypeError("invalid keyword arguments to print()")
+        if not want_unicode:
+            for arg in args:
+                if isinstance(arg, unicode):
+                    want_unicode = True
+                    break
+        if want_unicode:
+            newline = unicode("\n")
+            space = unicode(" ")
+        else:
+            newline = "\n"
+            space = " "
+        if sep is None:
+            sep = space
+        if end is None:
+            end = newline
+        for i, arg in enumerate(args):
+            if i:
+                write(sep)
+            write(arg)
+        write(end)
 
 
 _add_doc(reraise, """Reraise an exception.""")
 
 
 def with_metaclass(meta, *bases):
-  """Create a base class with a metaclass."""
-  return meta("NewBase", bases, {})
+    """Create a base class with a metaclass."""
+    return meta("NewBase", bases, {})
 
 
 def add_metaclass(metaclass):
-  """Class decorator for creating a class with a metaclass."""
+    """Class decorator for creating a class with a metaclass."""
 
-  def wrapper(cls):
-    orig_vars = cls.__dict__.copy()
-    orig_vars.pop('__dict__', None)
-    orig_vars.pop('__weakref__', None)
-    slots = orig_vars.get('__slots__')
-    if slots is not None:
-      if isinstance(slots, str):
-        slots = [slots]
-      for slots_var in slots:
-        orig_vars.pop(slots_var)
-    return metaclass(cls.__name__, cls.__bases__, orig_vars)
+    def wrapper(cls):
+        orig_vars = cls.__dict__.copy()
+        orig_vars.pop('__dict__', None)
+        orig_vars.pop('__weakref__', None)
+        slots = orig_vars.get('__slots__')
+        if slots is not None:
+            if isinstance(slots, str):
+                slots = [slots]
+            for slots_var in slots:
+                orig_vars.pop(slots_var)
+        return metaclass(cls.__name__, cls.__bases__, orig_vars)
+
+    return wrapper
 
-  return wrapper
 
 # added as part of the RDKit port
 if PY3:
 
-  def cmp(t1, t2):
-    return (t1 < t2) * -1 or (t1 > t2) * 1
+    def cmp(t1, t2):
+        return (t1 < t2) * -1 or (t1 > t2) * 1
 else:
-  cmp = cmp
+    cmp = cmp
